@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Sage documentation build configuration file, created by
 # sphinx-quickstart on Thu Aug 21 20:15:55 2008.
 #
@@ -14,8 +12,15 @@
 from sage.docs.conf import release
 from sage.docs.conf import *  # NOQA
 
+# Add any paths that contain custom static files (such as style sheets),
+# relative to this directory to html_static_path. They are copied after the
+# builtin static files, so a file named "default.css" will overwrite the
+# builtin "default.css". html_common_static_path imported from sage.docs.conf
+# contains common paths.
+html_static_path = [] + html_common_static_path
+
 # General information about the project.
-project = u"Introducció de Sage"
+project = "Introducció de Sage"
 
 # The name for this set of Sphinx documents.  If None, it defaults to
 # "<project> v<release> documentation".
@@ -27,6 +32,6 @@ htmlhelp_basename = 'TutorialdeSage'
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, document class [howto/manual]).
 latex_documents = [
-  ('index', 'TutorialdeSage.tex', u'Introducció de Sage',
-   u'The Sage Development Team', 'manual'),
+  ('index', 'TutorialdeSage.tex', 'Introducció de Sage',
+   'The Sage Development Team', 'manual'),
 ]
