@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Numerical Sage documentation build configuration file, created by
 # sphinx-quickstart on Sat Dec  6 11:08:04 2008.
 #
@@ -14,16 +12,23 @@
 from sage.docs.conf import release
 from sage.docs.conf import *  # NOQA
 
+# Add any paths that contain custom static files (such as style sheets),
+# relative to this directory to html_static_path. They are copied after the
+# builtin static files, so a file named "default.css" will overwrite the
+# builtin "default.css". html_common_static_path imported from sage.docs.conf
+# contains common paths.
+html_static_path = [] + html_common_static_path
+
 # General information about the project.
-project = u'Numerical Computing with Sage'
-copyright = u'2008, Josh Kantor'
+project = 'Numerical Computing with Sage'
+copyright = '2008, Josh Kantor'
 name = 'numerical_sage'
 
 # The name for this set of Sphinx documents.  If None, it defaults to
 # "<project> v<release> documentation".
-html_title = project + " v"+release
+html_title = project + " v" + release
 
-html_short_title = u'Numerical Sage v' + release
+html_short_title = 'Numerical Sage v' + release
 
 # Output file base name for HTML help builder.
 htmlhelp_basename = name
@@ -31,7 +36,7 @@ htmlhelp_basename = name
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, document class [howto/manual]).
 latex_documents = [
-  ('index', name+'.tex', u'Numerical Computing with Sage',
-   u'The Sage Development Team', 'manual'),
+  ('index', name + '.tex', 'Numerical Computing with Sage',
+   'The Sage Development Team', 'manual'),
 ]
 
