@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Sage documentation build configuration file, based on the file created by
 # sphinx-quickstart on Thu Aug 21 20:15:55 2008.
 #
@@ -14,14 +12,21 @@
 from sage.docs.conf import release
 from sage.docs.conf import *  # NOQA
 
+# Add any paths that contain custom static files (such as style sheets),
+# relative to this directory to html_static_path. They are copied after the
+# builtin static files, so a file named "default.css" will overwrite the
+# builtin "default.css". html_common_static_path imported from sage.docs.conf
+# contains common paths.
+html_static_path = [] + html_common_static_path
+
 # General information about the project.
-project = u"Tutorial Sage"
-name = u'tutorial-pt'
+project = "Tutorial Sage"
+name = 'tutorial-pt'
 language = "pt_BR"
 
 # The name for this set of Sphinx documents.  If None, it defaults to
 # "<project> v<release> documentation".
-html_title = project + " v"+release
+html_title = project + " v" + release
 
 # Output file base name for HTML help builder.
 htmlhelp_basename = name
@@ -29,6 +34,6 @@ htmlhelp_basename = name
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, document class [howto/manual]).
 latex_documents = [
-  ('index', name+'.tex', project,
-   u'The Sage Group', 'manual'),
+  ('index', name + '.tex', project,
+   'The Sage Group', 'manual'),
 ]
