@@ -351,7 +351,6 @@ mutating at the initial seed::
 # (at your option) any later version.
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
-from __future__ import absolute_import
 
 from copy import copy
 
@@ -364,6 +363,7 @@ from sage.functions.generalized import sign
 from sage.functions.other import binomial
 from sage.geometry.cone import Cone
 from sage.geometry.fan import Fan
+from sage.graphs.digraph import DiGraph
 from sage.matrix.constructor import identity_matrix, matrix
 from sage.matrix.special import block_matrix
 from sage.misc.cachefunc import cached_method
@@ -493,13 +493,11 @@ class PrincipalClusterAlgebraElement(ClusterAlgebraElement):
             sage: sum(A.initial_cluster_variables()).g_vector()
             Traceback (most recent call last):
             ...
-            ValueError: this element is not homogeneous
+            ValueError: this element does not have a well defined g-vector
         """
-        components = self.homogeneous_components()
-        if len(components) != 1:
-            raise ValueError("this element is not homogeneous")
-        k, = components
-        return k
+        if not self.is_homogeneous():
+            raise ValueError("this element does not have a well defined g-vector")
+        return self._g_vector
 
     def F_polynomial(self):
         r"""
@@ -515,17 +513,17 @@ class PrincipalClusterAlgebraElement(ClusterAlgebraElement):
             sage: sum(A.initial_cluster_variables()).F_polynomial()
             Traceback (most recent call last):
             ...
-            ValueError: this element is not homogeneous
+            ValueError: this element does not have a well defined g-vector
         """
         if not self.is_homogeneous():
-            raise ValueError("this element is not homogeneous")
-        subs_dict = dict()
+            raise ValueError("this element does not have a well defined g-vector")
+        subs_dict = {}
         A = self.parent()
         for x in A.initial_cluster_variables():
             subs_dict[x.lift()] = A._U(1)
         for i in range(A.rank()):
             subs_dict[A.coefficient(i).lift()] = A._U.gen(i)
-        return self.lift().substitute(subs_dict)
+        return A._U(self.lift().substitute(subs_dict))
 
     def is_homogeneous(self):
         r"""
@@ -541,7 +539,7 @@ class PrincipalClusterAlgebraElement(ClusterAlgebraElement):
             sage: x.is_homogeneous()
             False
         """
-        return len(self.homogeneous_components()) == 1
+        return getattr(self, '_is_homogeneous', len(self.homogeneous_components()) == 1)
 
     def homogeneous_components(self):
         r"""
@@ -561,7 +559,7 @@ class PrincipalClusterAlgebraElement(ClusterAlgebraElement):
         """
         deg_matrix = block_matrix([[identity_matrix(self.parent().rank()),
                                     -self.parent().b_matrix()]])
-        components = dict()
+        components = {}
         x = self.lift()
         monomials = x.monomials()
         for m in monomials:
@@ -570,8 +568,56 @@ class PrincipalClusterAlgebraElement(ClusterAlgebraElement):
                 components[g_vect] += self.parent().retract(x.monomial_coefficient(m) * m)
             else:
                 components[g_vect] = self.parent().retract(x.monomial_coefficient(m) * m)
+        for g_vect in components:
+            components[g_vect]._is_homogeneous = True
+            components[g_vect]._g_vector = g_vect
+        self._is_homogeneous = (len(components) == 1)
+        if self._is_homogeneous:
+            self._g_vector = list(components.keys())[0]
         return components
 
+    def theta_basis_decomposition(self):
+        r"""
+        Return the decomposition of ``self`` in the theta basis.
+
+        OUTPUT:
+
+        A dictionary whose keys are the g-vectors and whose values are the coefficients
+        in the decomposition of ``self`` in the theta basis.
+
+        EXAMPLES::
+
+            sage: A = ClusterAlgebra(matrix([[0,-2],[3,0]]), principal_coefficients=True)
+            sage: f = (A.theta_basis_element((1,0)) + A.theta_basis_element((0,1)))**2 + A.coefficient(1)* A.theta_basis_element((1,1))
+            sage: decomposition = f.theta_basis_decomposition()
+            sage: sum(decomposition[g] * A.theta_basis_element(g) for g in decomposition) == f
+            True
+            sage: f = A.theta_basis_element((4,-4))*A.theta_basis_element((1,-1))
+            sage: decomposition =  f.theta_basis_decomposition()
+            sage: sum(decomposition[g] * A.theta_basis_element(g) for g in decomposition) == f
+            True
+        """
+        A = self.parent()
+        B = A.b_matrix()
+        U = A._U
+        out = dict()
+        zero_A = A(0)
+        zero_U = U(0)
+        zero_t = (0,)*A.rank()
+
+        components = self.homogeneous_components()
+
+        for g_vect in components:
+            f_poly = components[g_vect].F_polynomial()
+            g_vect = vector(g_vect)
+            while f_poly != zero_U:
+                y_exp = min(f_poly.dict())
+                coeff = f_poly.dict()[y_exp]
+                g_theta = tuple(g_vect + B*vector(y_exp))
+                out[g_theta] = out.get(g_theta, zero_A) +  A({zero_t + tuple(y_exp):coeff})
+                f_poly -= U({y_exp:coeff}) * A.theta_basis_F_polynomial(g_theta)
+
+        return out
 
 ##############################################################################
 # Seeds
@@ -1261,7 +1307,7 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
             M0 = Q.b_matrix()[n:, :]
         m = M0.nrows()
 
-        B0 = block_matrix([[B0],[M0]])
+        B0 = block_matrix([[B0], [M0]])
         B0.set_immutable()
 
         # Determine the names of the initial cluster variables
@@ -1286,7 +1332,8 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
         # mutate_initial to name new cluster variables.
         splitnames = map(lambda w: w.partition(kwargs['cluster_variable_prefix']),
                 kwargs['cluster_variable_names'] + kwargs['coefficient_names'])
-        nfi = 1 + max( [-1] + [int(v) for u,_,v in splitnames if u == '' and v.isdigit()] )
+        nfi = 1 + max([-1] + [int(v) for u, _, v in splitnames
+                              if u == '' and v.isdigit()])
         kwargs.setdefault('next_free_index', nfi)
 
         # Determine scalars
@@ -1477,6 +1524,48 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
         # everything that is in the base can be coerced to self
         return self.base().has_coerce_map_from(other)
 
+    @cached_method
+    def coxeter_element(self):
+        r"""
+        Return the Coxeter element associated to the initial exchange matrix, if acyclic.
+
+        EXAMPLES::
+
+            sage: A = ClusterAlgebra(matrix([[0,1,1],[-1,0,1],[-1,-1,0]]))
+            sage: A.coxeter_element()
+            [0, 1, 2]
+
+        Raise an error if the initial exchange matrix is not acyclic::
+
+            sage: A = ClusterAlgebra(matrix([[0,1,-1],[-1,0,1],[1,-1,0]]))
+            sage: A.coxeter_element()
+            Traceback (most recent call last):
+            ...
+            ValueError: the initial exchange matrix is not acyclic.
+        """
+        dg = DiGraph(self.b_matrix().apply_map(lambda x: ZZ(0) if x <= 0 else ZZ(1)))
+        acyclic, coxeter = dg.is_directed_acyclic(certificate=True)
+        if not acyclic:
+            raise ValueError("the initial exchange matrix is not acyclic.")
+        return coxeter
+
+    @cached_method
+    def is_acyclic(self):
+        r"""
+        Return ``True`` if the exchange matrix in the initial seed is acyclic, ``False`` otherwise.
+
+        EXAMPLES::
+
+            sage: A = ClusterAlgebra(matrix([[0,1,1],[-1,0,1],[-1,-1,0]]))
+            sage: A.is_acyclic()
+            True
+            sage: A = ClusterAlgebra(matrix([[0,1,-1],[-1,0,1],[1,-1,0]]))
+            sage: A.is_acyclic()
+            False
+        """
+        dg = DiGraph(self.b_matrix().apply_map(lambda x: ZZ(0) if x <= 0 else ZZ(1)))
+        return dg.is_directed_acyclic()
+
     def rank(self):
         r"""
         Return the rank of ``self``, i.e. the number of cluster variables
@@ -1530,12 +1619,12 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
             sage: A.set_current_seed(A1.initial_seed())
             Traceback (most recent call last):
             ...
-            ValueError: This is not a seed in this cluster algebra
+            ValueError: this is not a seed in this cluster algebra
         """
         if self.contains_seed(seed):
             self._seed = seed
         else:
-            raise ValueError("This is not a seed in this cluster algebra")
+            raise ValueError("this is not a seed in this cluster algebra")
 
     def reset_current_seed(self):
         r"""
@@ -1627,6 +1716,92 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
         n = self.rank()
         return copy(self._B0[:n, :])
 
+    def euler_matrix(self):
+        r"""
+        Return the Euler matrix associated to ``self``.
+
+        ALGORITHM:
+
+            This method returns the matrix of the bilinear form defined in Equation (2.1) of [ReSt2020]_ .
+
+        EXAMPLES::
+
+            sage: A = ClusterAlgebra(matrix([[0,1,1],[-1,0,1],[-1,-1,0]]))
+            sage: A.euler_matrix()
+            [ 1  0  0]
+            [-1  1  0]
+            [-1 -1  1]
+
+        Raise an error if the initial exchange matrix is not acyclic::
+
+            sage: A = ClusterAlgebra(matrix([[0,1,-1],[-1,0,1],[1,-1,0]]))
+            sage: A.euler_matrix()
+            Traceback (most recent call last):
+            ...
+            ValueError: the initial exchange matrix is not acyclic.
+        """
+
+        if not self.is_acyclic():
+            raise ValueError("the initial exchange matrix is not acyclic.")
+        return 1 + self.b_matrix().apply_map(lambda x: min(ZZ(0), x))
+
+    def d_vector_to_g_vector(self, d):
+        r"""
+        Return the g-vector of an element of ``self`` having d-vector ``d``
+
+        INPUT:
+
+        - ``d`` -- the d-vector
+
+        ALGORITHM:
+
+            This method implements the piecewise-linear map `\\nu_c` introduced in Section 9.1 of [ReSt2020]_.
+
+        .. WARNING:
+
+            This implementation works only when the initial exchange matrix is acyclic.
+
+        EXAMPLES::
+
+            sage: A = ClusterAlgebra(matrix([[0,1,1],[-1,0,1],[-1,-1,0]]))
+            sage: A.d_vector_to_g_vector((1,0,-1))
+            (-1, 1, 2)
+        """
+        dm = vector(( x if x < 0 else 0 for x in d))
+        dp = vector(d) - dm
+        return tuple(- dm - self.euler_matrix()*dp)
+
+    def g_vector_to_d_vector(self, g):
+        r"""
+        Return the d-vector of an element of ``self`` having g-vector ``g``
+
+        INPUT:
+
+        - ``g`` -- the g-vector
+
+        ALGORITHM:
+
+            This method implements the inverse of the piecewise-linear map `\\nu_c` introduced in Section 9.1 of [ReSt2020]_.
+
+        .. WARNING:
+
+            This implementation works only when the initial exchange matrix is acyclic.
+
+        EXAMPLES::
+
+            sage: A = ClusterAlgebra(matrix([[0,1,1],[-1,0,1],[-1,-1,0]]))
+            sage: A.g_vector_to_d_vector((-1,1,2))
+            (1, 0, -1)
+        """
+        E = -self.euler_matrix()
+        c = self.coxeter_element()
+        dp = vector(ZZ, self.rank())
+        g = vector(g)
+        for i in c:
+            dp[i] = -min(g[i], 0)
+            g += min(g[i],0)*E.column(i)
+        return tuple(-g+dp)
+
     def g_vectors(self, mutating_F=True):
         r"""
         Return an iterator producing all the g-vectors of ``self``.
@@ -2337,7 +2512,7 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
                     tmp_path_dict[new_g_vect] = new_path
 
             # update storage
-            initial_g = (0,)*(k)+(1,)+(0,)*(n-k-1)
+            initial_g = (0,) * (k) + (1,) + (0,) * (n - k - 1)
             tmp_path_dict[initial_g] = []
             path_dict = tmp_path_dict
             path_to_current = ([k] + path_to_current[:1] if path_to_current[:1] != [k] else []) + path_to_current[1:]
@@ -2349,7 +2524,8 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
         # create new algebra
         coeff_names = self.coefficient_names()
         scalars = self.scalars()
-        A = ClusterAlgebra(B0, cluster_variable_names=cv_names, next_free_index = nfi,
+        A = ClusterAlgebra(B0, cluster_variable_names=cv_names,
+                           next_free_index=nfi,
                            coefficient_names=coeff_names, scalars=scalars)
 
         # store computed data
@@ -2393,28 +2569,112 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
         if self.rank() != 2:
             raise ValueError('greedy elements are only defined in rank 2')
 
-        if len(self.coefficients()) != 0:
-            raise NotImplementedError('can only compute greedy elements in the coefficient-free case')
+        return self.theta_basis_element(self.d_vector_to_g_vector(d_vector))
 
-        b = abs(self.b_matrix()[0, 1])
-        c = abs(self.b_matrix()[1, 0])
-        a1, a2 = d_vector
-        # Here we use the generators of self.ambient() because cluster variables
-        #   do not have an inverse.
-        x1, x2 = self.ambient().gens()
-        if a1 < 0:
-            if a2 < 0:
-                return self.retract(x1 ** (-a1) * x2 ** (-a2))
-            else:
-                return self.retract(x1 ** (-a1) * ((1 + x2 ** c) / x1) ** a2)
-        elif a2 < 0:
-            return self.retract(((1 + x1 ** b) / x2) ** a1 * x2 ** (-a2))
-        output = 0
-        for p in range(0, a2 + 1):
-            for q in range(0, a1 + 1):
-                output += self._greedy_coefficient(d_vector, p, q) * x1 ** (b * p) * x2 ** (c * q)
-        return self.retract(x1 ** (-a1) * x2 ** (-a2) * output)
+    @cached_method(key=lambda a, b: tuple(b))
+    def theta_basis_element(self, g_vector):
+        r"""
+        Return the element of the theta basis of ``self`` with g-vector ``g_vector``.
 
+        INPUT:
+
+        - ``g_vector`` -- tuple; the g-vector of the element to compute
+
+        EXAMPLES::
+
+            sage: A = ClusterAlgebra(matrix([[0,-3],[2,0]]), principal_coefficients=True)
+            sage: A.theta_basis_element((-1,-1))
+            (x1^8*y0^4*y1 + 4*x1^6*y0^3*y1 + 6*x1^4*y0^2*y1 + x0^3*x1^2*y0 + 4*x1^2*y0*y1 + x0^3 + y1)/(x0^4*x1)
+
+            sage: A = ClusterAlgebra(['F', 4])
+            sage: A.theta_basis_element((1, 0, 0, 0))
+            Traceback (most recent call last):
+            ...
+            NotImplementedError: Currently only implemented for cluster algebras of rank 2.
+
+        .. NOTE::
+
+            Elements of the theta basis correspond with the associated cluster
+            monomial only for appropriate coefficient choices. For example::
+
+                sage: A = ClusterAlgebra(matrix([[0,-1],[1,0],[-1,0]]))
+                sage: A.theta_basis_element((-1,0))
+                (x1 + y0)/(x0*y0)
+
+            while::
+
+                sage: _ = A.find_g_vector((-1,0));
+                sage: A.cluster_variable((-1,0))
+                (x1 + y0)/x0
+
+            In particular theta basis elements do not satisfy a separation of additions formula.
+
+        .. WARNING::
+
+            Currently only cluster algebras of rank 2 are supported
+
+        .. SEEALSO::
+
+            :meth:`sage.algebras.cluster_algebra.theta_basis_F_polynomial`
+        """
+        g_vector = tuple(g_vector)
+        F = self.theta_basis_F_polynomial(g_vector).subs(self._yhat)
+        g_mon = prod(self.ambient().gen(i) ** g_vector[i] for i in range(self.rank()))
+        # we only return the monomal g_mon times the evaluated F-polynomial because this is how
+        # theta basis elements behave.
+        return self.retract(g_mon * F)
+
+    @cached_method(key=lambda a, b: tuple(b))
+    def theta_basis_F_polynomial(self, g_vector):
+        r"""
+        Return the F-polynomial of the element of the theta basis of ``self`` with g-vector ``g_vector``.
+
+        INPUT:
+
+        - ``g_vector`` -- tuple; the g-vector of the F-polynomial to compute
+
+        .. WARNING::
+
+            Elements of the theta basis do not satisfy a separation of additions formula.
+            See the implementation of :meth:`sage.algebras.cluster_algebra.theta_basis_F_polynomial`
+            for further details.
+
+        ALGORITHM:
+
+        This method uses the fact that the greedy basis and the theta basis
+        coincide in rank 2 and uses the former defining recursion (Equation
+        (1.5) from [LLZ2014]_) to compute.
+
+        EXAMPLES::
+
+            sage: A = ClusterAlgebra(matrix([[0,-3],[2,0]]), principal_coefficients=True)
+            sage: A.theta_basis_F_polynomial((-1,-1))
+            u0^4*u1 + 4*u0^3*u1 + 6*u0^2*u1 + 4*u0*u1 + u0 + u1 + 1
+
+            sage: A = ClusterAlgebra(['F', 4])
+            sage: A.theta_basis_F_polynomial((1, 0, 0, 0))
+            Traceback (most recent call last):
+            ...
+            NotImplementedError: Currently only implemented for cluster algebras of rank 2.
+        """
+        if self.rank() != 2:
+            raise NotImplementedError("Currently only implemented for cluster algebras of rank 2.")
+
+        # extract the part of g_vector not coming from the initial cluster
+        d = tuple( max(x, 0) for x in self.g_vector_to_d_vector(g_vector) )
+        g = self.d_vector_to_g_vector(d)
+
+        shifts = ((d[0]+g[0])/self._B0[0, 1], (d[1]+g[1])/self._B0[1, 0] )
+        signs = ( sign(self._B0[0, 1]), sign(self._B0[1, 0]) )
+
+        u = list(self._U.gens())
+        output = self._U.zero()
+        for p in range(0, d[1] + 1):
+            for q in range(0, d[0] + 1):
+                output += self._greedy_coefficient(d, p, q) * u[1] ** (signs[0]*p - shifts[0]) * u[0] ** (signs[1]*q - shifts[1])
+        return output
+
+    @cached_method
     def _greedy_coefficient(self, d_vector, p, q):
         r"""
         Return the coefficient of the monomial ``x1 ** (b * p) * x2 ** (c * q)``
@@ -2430,8 +2690,8 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
             sage: A._greedy_coefficient((1, 1), 1, 0)
             1
         """
-        b = abs(self.b_matrix()[0, 1])
-        c = abs(self.b_matrix()[1, 0])
+        b = abs(self._B0[0, 1])
+        c = abs(self._B0[1, 0])
         a1, a2 = d_vector
         p = Integer(p)
         q = Integer(q)
@@ -2494,17 +2754,3 @@ class ClusterAlgebra(Parent, UniqueRepresentation):
             NotImplementedError: not implemented yet
         """
         raise NotImplementedError("not implemented yet")
-
-    def theta_basis_element(self, g_vector):
-        r"""
-        Return the element of the theta basis with g-vector ``g_vector``.
-
-        EXAMPLES::
-
-            sage: A = ClusterAlgebra(['F', 4])
-            sage: A.theta_basis_element((1, 0, 0, 0))
-            Traceback (most recent call last):
-            ...
-            NotImplementedError: not implemented yet
-        """
-        raise NotImplementedError("not implemented yet")
