@@ -11,8 +11,6 @@ AUTHORS:
 #  Distributed under the terms of the GNU General Public License (GPL)
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
-# python3
-from __future__ import division
 
 from sage.misc.misc_c import prod
 from sage.misc.cachefunc import cached_method
@@ -118,7 +116,7 @@ class HallAlgebra(CombinatorialFreeModule):
     `n(\lambda) = \sum_i (i - 1) \lambda_i`.
 
     See section 2.3 in [Sch2006]_, and sections II.2 and III.3
-    in [Macdonald1995]_ (where our `I_{\lambda}` is called `u_{\lambda}`).
+    in [Mac1995]_ (where our `I_{\lambda}` is called `u_{\lambda}`).
 
     EXAMPLES::
 
