@@ -1,11 +1,10 @@
-from __future__ import absolute_import
 from sage.misc.lazy_import import lazy_import
 
 from .category import Category
 
 from .category_types import Elements
 
-from .chain_complexes import ChainComplexes
+from .chain_complexes import ChainComplexes, HomologyFunctor
 
 from .simplicial_complexes import SimplicialComplexes
 
