@@ -336,9 +336,20 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
                 sage: x = C.basis()
                 sage: C.echelon_form([x[0] - x[1], 2*x[1] - 2*x[2], x[0] - x[2]])
                 [x[0] - x[2], x[1] - x[2]]
+
+            ::
+
+                sage: M = MatrixSpace(QQ, 3, 3)                                                                                     
+                sage: A = M([[0, 0, 2], [0, 0, 0], [0, 0, 0]])                                                                      
+                sage: M.echelon_form([A, A])                                                                                         
+                [
+                [0 0 1]
+                [0 0 0]
+                [0 0 0]
+                ]
             """
             if order is not None:
-                order = self._compute_support_order(order)
+                order = self._compute_support_order(elements, order)
             from sage.matrix.constructor import matrix
             mat = matrix(self.base_ring(), [g._vector_(order=order) for g in elements])
             # Echelonizing a matrix over a field returned the rref
@@ -352,6 +363,127 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
             ret = [self.from_vector(vec, order=order) for vec in mat if vec]
             return ret
 
+        def invariant_module(self, S, action=operator.mul, action_on_basis=None,
+                             side="left", **kwargs):
+            r"""
+            Return the submodule of ``self`` invariant under the action
+            of ``S``.
+
+            For a semigroup `S` acting on a module `M`, the invariant
+            submodule is given by
+
+            .. MATH::
+
+                M^S = \{m \in M : s \cdot m = m,\, \forall s \in S\}.
+
+            INPUT:
+
+            - ``S`` -- a finitely-generated semigroup
+            - ``action`` -- a function (default: :obj:`operator.mul`)
+            - ``side`` -- ``'left'`` or ``'right'`` (default: ``'right'``);
+              which side of ``self`` the elements of ``S`` acts
+            - ``action_on_basis`` -- (optional) define the action of ``S``
+              on the basis of ``self``
+
+            OUTPUT:
+
+            - :class:`~sage.modules.with_basis.invariant.FiniteDimensionalInvariantModule`
+
+            EXAMPLES:
+
+            We build the invariant module of the permutation representation
+            of the symmetric group::
+
+                sage: G = SymmetricGroup(3); G.rename('S3')
+                sage: M = FreeModule(ZZ, [1,2,3], prefix='M'); M.rename('M')
+                sage: action = lambda g, x: M.term(g(x))
+                sage: I = M.invariant_module(G, action_on_basis=action); I
+                (S3)-invariant submodule of M
+                sage: I.basis()
+                Finite family {0: B[0]}
+                sage: [I.lift(b) for b in I.basis()]
+                [M[1] + M[2] + M[3]]
+
+                sage: G.rename(); M.rename()  # reset the names
+
+            We can construct the invariant module of any module that has
+            an action of ``S``. In this example, we consider the dihedral
+            group `G = D_4` and the subgroup `H < G` of all rotations. We
+            construct the `H`-invariant module of the group algebra `\QQ[G]`::
+
+                sage: G = groups.permutation.Dihedral(4)
+                sage: H = G.subgroup(G.gen(0))
+                sage: H
+                Subgroup generated by [(1,2,3,4)] of (Dihedral group of order 8 as a permutation group)
+                sage: H.cardinality()
+                4
+                sage: A = G.algebra(QQ)
+                sage: I = A.invariant_module(H)
+                sage: [I.lift(b) for b in I.basis()]
+                [() + (1,2,3,4) + (1,3)(2,4) + (1,4,3,2),
+                 (2,4) + (1,2)(3,4) + (1,3) + (1,4)(2,3)]
+                sage: all(h * I.lift(b) == I.lift(b) for b in I.basis() for h in H)
+                True
+            """
+            if action_on_basis is not None:
+                from sage.modules.with_basis.representation import Representation
+                M = Representation(S, self, action_on_basis, side=side)
+            else:
+                M = self
+
+            from sage.modules.with_basis.invariant import FiniteDimensionalInvariantModule
+            return FiniteDimensionalInvariantModule(M, S, action=action, side=side, **kwargs)
+
+        def twisted_invariant_module(self, G, chi,
+                                     action=operator.mul,
+                                     action_on_basis=None,
+                                     side='left',
+                                     **kwargs):
+            r"""
+            Create the isotypic component of the action of ``G`` on
+            ``self`` with irreducible character given by ``chi``.
+
+            .. SEEALSO:
+
+                -:class:`~sage.modules.with_basis.invariant.FiniteDimensionalTwistedInvariantModule`
+
+            INPUT:
+
+            - ``G`` -- a finitely-generated group
+            - ``chi`` -- a list/tuple of character values or an instance of
+              :class:`~sage.groups.class_function.ClassFunction_gap`
+            - ``action`` -- a function (default: :obj:`operator.mul`)
+            - ``action_on_basis`` -- (optional) define the action of ``g``
+              on the basis of ``self``
+            - ``side`` -- ``'left'`` or ``'right'`` (default: ``'right'``);
+              which side of ``self`` the elements of ``S`` acts
+
+            OUTPUT:
+
+            - :class:`~sage.modules.with_basis.invariant.FiniteDimensionalTwistedInvariantModule`
+
+            EXAMPLES::
+
+                sage: M = CombinatorialFreeModule(QQ, [1,2,3])
+                sage: G = SymmetricGroup(3)
+                sage: def action(g,x): return(M.term(g(x))) # permute coordinates
+                sage: T = M.twisted_invariant_module(G, [2,0,-1], action_on_basis=action)
+                sage: import __main__; __main__.action = action
+                sage: TestSuite(T).run()
+            """
+
+            if action_on_basis is not None:
+                from sage.modules.with_basis.representation import Representation
+                from sage.categories.modules import Modules
+                category = kwargs.pop('category', Modules(self.base_ring()).WithBasis())
+                M = Representation(G, self, action_on_basis, side=side, category=category)
+            else:
+                M = self
+
+            from sage.modules.with_basis.invariant import FiniteDimensionalTwistedInvariantModule
+            return FiniteDimensionalTwistedInvariantModule(M, G, chi,
+                                                          action, side, **kwargs)
+
     class ElementMethods:
         def dense_coefficient_list(self, order=None):
             """
@@ -394,7 +526,11 @@ class FiniteDimensionalModulesWithBasis(CategoryWithAxiom_over_base_ring):
                 sage: C.an_element()._vector_()
                 (2, 2, 3)
             """
-            dense_free_module = self.parent()._dense_free_module()
+            if order is None:
+                dense_free_module = self.parent()._dense_free_module()
+            else:
+                from sage.modules.free_module import FreeModule
+                dense_free_module = FreeModule(self.parent().base_ring(), len(order))
             # We slightly break encapsulation for speed reasons
             return dense_free_module.element_class(dense_free_module,
                                                    self.dense_coefficient_list(order),
