@@ -1,7 +1,6 @@
 r"""
 Magmas
 """
-from __future__ import absolute_import
 # ****************************************************************************
 #  Copyright (C) 2010 Nicolas M. Thiery <nthiery at users.sf.net>
 #
@@ -22,6 +21,7 @@ from sage.categories.sets_cat import Sets
 from sage.categories.realizations import RealizationsCategory
 from sage.cpython.getattr import raw_getattr
 
+
 class Magmas(Category_singleton):
     """
     The category of (multiplicative) magmas.
@@ -283,7 +283,7 @@ class Magmas(Category_singleton):
             subcategory of both :class:`Magmas` and
             :class:`AdditiveMagmas` and upgrades it to a subcategory
             of :class:`MagmasAndAdditiveMagmas` before applying the
-            axiom. It complains overwise, since the ``Distributive``
+            axiom. It complains otherwise, since the ``Distributive``
             axiom does not make sense for a plain magma.
 
             EXAMPLES::
@@ -367,7 +367,6 @@ class Magmas(Category_singleton):
             from sage.categories.magmatic_algebras import MagmaticAlgebras
             return [MagmaticAlgebras(self.base_ring())]
 
-
         class ParentMethods:
             def is_field(self, proof=True):
                 r"""
@@ -1117,7 +1116,7 @@ class Magmas(Category_singleton):
                     sage: x*y
                     B[(0, [1, 2, 3])] + B[(1, [3, 1, 2])]
                 """
-                return self._cartesian_product_of_elements([(a*b) for (a,b) in zip(left.cartesian_factors(), right.cartesian_factors())])
+                return self._cartesian_product_of_elements( (a*b) for (a,b) in zip(left.cartesian_factors(), right.cartesian_factors()) )
 
     class Subquotients(SubquotientsCategory):
         r"""
