@@ -15,7 +15,6 @@ Ribbon Tableaux
 #
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
-from __future__ import division, print_function, absolute_import
 
 from sage.structure.parent import Parent
 from sage.structure.element import parent
@@ -504,10 +503,10 @@ def count_rec(nexts, current, part, weight, length):
         sage: count_rec([[4], [1]], [[[4, 2, 2], [0, 0, 2, 0]], [[4, 3, 1], [0, 2, 0, 0]]], [[4, 3, 3], []], [2, 1, 1, 1], 2)
         [5]
     """
-    if current == []:
+    if not current:
         return [0]
-    if nexts != []:
-        return [sum(sum(j for j in i) for i in nexts)]
+    if nexts:
+        return [sum(j for i in nexts for j in i)]
     else:
         return [len(current)]
 
@@ -550,11 +549,11 @@ def list_rec(nexts, current, part, weight, length):
         return [[part[1],[]]]
 
     ## Test if the current nodes is not an empty node
-    if current == []:
+    if not current:
         return []
 
     ## Test if the current nodes drive us to new solutions
-    if nexts != []:
+    if nexts:
         res = []
         for i in range(len(current)):
             for j in range(len(nexts[i])):
@@ -758,8 +757,8 @@ def graph_implementation_rec(skp, weight, length, function):
     outer = skp[1]
     outer_len = len(outer)
 
-    ## Some tests in order to know if the shape and the weight are compatible.
-    if weight != [] and weight[-1] <= len(partp):
+    # Some tests in order to know if the shape and the weight are compatible.
+    if weight and weight[-1] <= len(partp):
         perms = permutation.Permutations([0]*(len(partp)-weight[-1]) + [length]*(weight[-1])).list()
     else:
         return function([], [], skp, weight, length)
@@ -1111,14 +1110,13 @@ class SemistandardMultiSkewTableaux(MultiSkewTableaux):
         parts = self._shape
         mu = self._weight
 
-        #Splitting the partition
-        s = [ p.size() for p in parts ]
+        # Splitting the partition
+        s = [p.size() for p in parts]
         parts = [p.to_list() for p in parts]
 
-        #Gluing the partitions
+        # Gluing the partitions
         parttmp = parts[0]
-        i = 1
-        for i in range(1,len(parts)):
+        for i in range(1, len(parts)):
             trans = parttmp[0][0]
             current_part = parts[i]
             current_part[1] += [0]*(len(current_part[0])-len(current_part[1]))
@@ -1126,7 +1124,7 @@ class SemistandardMultiSkewTableaux(MultiSkewTableaux):
             outer_current = [ trans + j for j in current_part[0] ]
             parttmp = [ outer_current + parttmp[0], inner_current + parttmp[1] ]
 
-        #List the corresponding skew tableaux
+        # List the corresponding skew tableaux
         l = [ st.to_word() for st in SemistandardSkewTableaux(parttmp, mu) ]
 
         S = SkewTableaux()
