@@ -13,7 +13,7 @@ Representations of the Symmetric Group
     Group"
 
 """
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2009 Franco Saliola <saliola@gmail.com>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
@@ -25,15 +25,13 @@ Representations of the Symmetric Group
 #
 #  The full text of the GPL is available at:
 #
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
-from __future__ import print_function
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
 from sage.symbolic.ring import SR
 from sage.functions.all import sqrt
-from sage.combinat.combinat import CombinatorialClass
 from sage.combinat.partition import Partition, Partitions
-from sage.combinat.permutation import Permutation, Permutations
+from sage.combinat.permutation import Permutation, Permutations, from_cycles
 from sage.combinat.tableau import StandardTableaux, Tableau
 from sage.combinat.yang_baxter_graph import YangBaxterGraph_partition
 from sage.groups.perm_gps.constructor import PermutationGroupElement as PermutationConstructor
@@ -42,9 +40,13 @@ from sage.misc.cachefunc import cached_method
 from sage.misc.lazy_attribute import lazy_attribute
 from sage.rings.integer_ring import ZZ
 from sage.rings.rational_field import QQ
-from sage.structure.sage_object import SageObject
+from sage.structure.parent import Parent
+from sage.structure.element import Element
+from sage.structure.unique_representation import UniqueRepresentation
+from sage.sets.finite_enumerated_set import FiniteEnumeratedSets
+
+# #### Constructor function ################################################
 
-##### Constructor function ################################################
 
 def SymmetricGroupRepresentation(partition, implementation="specht",
         ring=None, cache_matrices=True):
@@ -57,14 +59,15 @@ def SymmetricGroupRepresentation(partition, implementation="specht",
     - ``partition`` -- a partition of a positive integer
 
     - ``implementation`` -- string (default: ``"specht"``), one of:
-        - ``"seminormal"`` - for Young's seminormal representation
-        - ``"orthogonal"`` - for Young's orthogonal representation
-        - ``"specht"`` - for Specht's representation
 
-    - ``ring`` -- the ring over which the representation is defined.
+      * ``"seminormal"`` - for Young's seminormal representation
+      * ``"orthogonal"`` - for Young's orthogonal representation
+      * ``"specht"`` - for Specht's representation
+
+    - ``ring`` -- the ring over which the representation is defined
 
     - ``cache_matrices`` -- boolean (default: ``True``) if ``True``, then any
-      representation matrices that are computed are cached.
+      representation matrices that are computed are cached
 
     EXAMPLES:
 
@@ -100,7 +103,7 @@ def SymmetricGroupRepresentation(partition, implementation="specht",
         [          0           0           0           1           0]
         [          0           0           0           0          -1]
 
-    The Specht Representation::
+    The Specht representation::
 
         sage: spc = SymmetricGroupRepresentation([3,2], "specht")
         sage: spc.scalar_product_matrix(Permutation([1,2,3,4,5]))
@@ -140,7 +143,7 @@ def SymmetricGroupRepresentation(partition, implementation="specht",
         [ 0  1 -1 -1  1]
         [ 0  1  0 -1  1]}
 
-    This can be turned off with the keyword cache_matrices::
+    This can be turned off with the keyword ``cache_matrices``::
 
         sage: spc = SymmetricGroupRepresentation([3,2], "specht", cache_matrices=False)
         sage: spc([5,4,3,2,1])
@@ -166,17 +169,9 @@ def SymmetricGroupRepresentation(partition, implementation="specht",
     - Franco Saliola (2009-04-23)
     """
     partition = Partition(partition)
-    if implementation == "seminormal":
-        return YoungRepresentation_Seminormal(partition, ring=ring,
-                cache_matrices=cache_matrices)
-    elif implementation == "orthogonal":
-        return YoungRepresentation_Orthogonal(partition, ring=ring,
-                cache_matrices=cache_matrices)
-    elif implementation == "specht":
-        return SpechtRepresentation(partition, ring=ring,
-                cache_matrices=cache_matrices)
-    else:
-        raise NotImplementedError("only seminormal, orthogonal and specht are implemented")
+    Rep = SymmetricGroupRepresentations(sum(partition), implementation=implementation,
+                                        ring=ring, cache_matrices=cache_matrices)
+    return Rep(partition)
 
 def SymmetricGroupRepresentations(n, implementation="specht", ring=None,
         cache_matrices=True):
@@ -188,14 +183,15 @@ def SymmetricGroupRepresentations(n, implementation="specht", ring=None,
     - ``n`` -- positive integer
 
     - ``implementation`` -- string (default: ``"specht"``), one of:
-        - ``"seminormal"`` - for Young's seminormal representation
-        - ``"orthogonal"`` - for Young's orthogonal representation
-        - ``"specht"`` - for Specht's representation
 
-    - ``ring`` -- the ring over which the representation is defined.
+      * ``"seminormal"`` - for Young's seminormal representation
+      * ``"orthogonal"`` - for Young's orthogonal representation
+      * ``"specht"`` - for Specht's representation
+
+    - ``ring`` -- the ring over which the representation is defined
 
     - ``cache_matrices`` -- boolean (default: ``True``) if ``True``, then any
-      representation matrices that are computed are cached.
+      representation matrices that are computed are cached
 
     EXAMPLES:
 
@@ -206,7 +202,9 @@ def SymmetricGroupRepresentations(n, implementation="specht", ring=None,
         sage: orth = SymmetricGroupRepresentations(3, "orthogonal"); orth
         Orthogonal representations of the symmetric group of order 3! over Symbolic Ring
         sage: orth.list()
-        [Orthogonal representation of the symmetric group corresponding to [3], Orthogonal representation of the symmetric group corresponding to [2, 1], Orthogonal representation of the symmetric group corresponding to [1, 1, 1]]
+        [Orthogonal representation of the symmetric group corresponding to [3],
+         Orthogonal representation of the symmetric group corresponding to [2, 1],
+         Orthogonal representation of the symmetric group corresponding to [1, 1, 1]]
         sage: orth([2,1])([1,2,3])
         [1 0]
         [0 1]
@@ -244,23 +242,24 @@ def SymmetricGroupRepresentations(n, implementation="specht", ring=None,
     - Franco Saliola (2009-04-23)
     """
     if implementation == "seminormal":
-        return YoungRepresentations_Seminormal(n, ring=ring)
+        return YoungRepresentations_Seminormal(n, ring=ring, cache_matrices=cache_matrices)
     elif implementation == "orthogonal":
-        return YoungRepresentations_Orthogonal(n, ring=ring)
+        return YoungRepresentations_Orthogonal(n, ring=ring, cache_matrices=cache_matrices)
     elif implementation == "specht":
-        return SpechtRepresentations(n, ring=ring)
+        return SpechtRepresentations(n, ring=ring, cache_matrices=cache_matrices)
     else:
         raise NotImplementedError("only seminormal, orthogonal and specht are implemented")
 
-##### Generic classes for symmetric group representations #################
+# #### Generic classes for symmetric group representations #################
 
-class SymmetricGroupRepresentation_generic_class(SageObject):
+
+class SymmetricGroupRepresentation_generic_class(Element):
     r"""
     Generic methods for a representation of the symmetric group.
     """
     _default_ring = None
 
-    def __init__(self, partition, ring=None, cache_matrices=True):
+    def __init__(self, parent, partition):
         r"""
         An irreducible representation of the symmetric group corresponding
         to ``partition``.
@@ -283,9 +282,11 @@ class SymmetricGroupRepresentation_generic_class(SageObject):
             True
         """
         self._partition = Partition(partition)
-        self._ring = ring if not ring is None else self._default_ring
-        if cache_matrices is False:
+        self._n = parent._n
+        self._ring = parent._ring
+        if not parent._cache_matrices:
             self.representation_matrix = self._representation_matrix_uncached
+        Element.__init__(self, parent)
 
     def __hash__(self):
         r"""
@@ -318,6 +319,8 @@ class SymmetricGroupRepresentation_generic_class(SageObject):
             sage: spc4 = loads(dumps(spc3))
             sage: spc3 == spc4
             True
+            sage: spc1 == spc3
+            True
 
         TESTS:
 
@@ -327,11 +330,28 @@ class SymmetricGroupRepresentation_generic_class(SageObject):
             sage: spc.important_info = 'Sage rules'
             sage: spc == SymmetricGroupRepresentation([3])
             True
-
         """
         if not isinstance(other, type(other)):
             return False
-        return (self._ring,self._partition)==(other._ring,other._partition)
+        return (self._ring, self._partition) == (other._ring, other._partition)
+
+    def __ne__(self, other):
+        """
+        Test for inequality.
+
+        EXAMPLES::
+
+            sage: spc1 = SymmetricGroupRepresentation([3], cache_matrices=True)
+            sage: loads(dumps(spc1)) != spc1
+            False
+            sage: spc2 = SymmetricGroupRepresentation([2,1])
+            sage: spc1 != spc2
+            True
+            sage: spc3 = SymmetricGroupRepresentation([3], cache_matrices=False)
+            sage: spc1 != spc3
+            False
+        """
+        return not (self == other)
 
     def __call__(self, permutation):
         r"""
@@ -357,8 +377,8 @@ class SymmetricGroupRepresentation_generic_class(SageObject):
             sage: list(spc)
             [[1], [-1], [-1], [1], [1], [-1]]
         """
-        for permutation in Permutations(self._partition.size()):
-            yield self.representation_matrix(permutation)
+        for permutation in Permutations(self._n):
+             yield self.representation_matrix(permutation)
 
     def verify_representation(self):
         r"""
@@ -375,23 +395,20 @@ class SymmetricGroupRepresentation_generic_class(SageObject):
             sage: spc.verify_representation()
             True
         """
-        n = self._partition.size()
-        transpositions = []
-        for i in range(1, n):
-            si = Permutation(list(range(1,i)) + [i+1,i] + list(range(i+2,n+1)))
-            transpositions.append(si)
-        repn_matrices = [self.representation_matrix(_) for _ in transpositions]
-        for (i,si) in enumerate(repn_matrices):
-            for (j,sj) in enumerate(repn_matrices):
+        n = self._n
+        transpositions = [from_cycles(n, ((i, i + 1),)) for i in range(1, n)]
+        repn_matrices = [self.representation_matrix(t) for t in transpositions]
+        for i, si in enumerate(repn_matrices):
+            for j, sj in enumerate(repn_matrices):
                 if i == j:
-                    if si*sj != si.parent().identity_matrix():
+                    if si * sj != si.parent().identity_matrix():
                         return False, "si si != 1 for i = %s" % (i,)
-                elif abs(i-j) > 1:
-                    if si*sj != sj*si:
-                        return False, "si sj != sj si for (i,j) =(%s,%s)" % (i,j)
+                elif abs(i - j) > 1:
+                    if si * sj != sj * si:
+                        return False, "si sj != sj si for (i,j) =(%s,%s)" % (i, j)
                 else:
-                    if si*sj*si != sj*si*sj:
-                        return False, "si sj si != sj si sj for (i,j) = (%s,%s)" % (i,j)
+                    if si * sj * si != sj * si * sj:
+                        return False, "si sj si != sj si sj for (i,j) = (%s,%s)" % (i, j)
         return True
 
     def to_character(self):
@@ -429,14 +446,14 @@ class SymmetricGroupRepresentation_generic_class(SageObject):
             [4, 2, 2, 1, 1, 2, 2, 0, 1, 0, 0, 1, 1, 0, 2, 1, 0, 0, 0, 1, 1, 2, 0, 0]
             sage: [p.to_matrix().trace() for p in Permutations(4)]
             [4, 2, 2, 1, 1, 2, 2, 0, 1, 0, 0, 1, 1, 0, 2, 1, 0, 0, 0, 1, 1, 2, 0, 0]
-
         """
         from sage.groups.perm_gps.permgroup_named import SymmetricGroup
         Sym = SymmetricGroup(sum(self._partition))
         values = [self(g).trace() for g in Sym.conjugacy_classes_representatives()]
         return Sym.character(values)
 
-class SymmetricGroupRepresentations_class(CombinatorialClass):
+
+class SymmetricGroupRepresentations_class(UniqueRepresentation,Parent):
     r"""
     Generic methods for the CombinatorialClass of irreducible
     representations of the symmetric group.
@@ -455,12 +472,13 @@ class SymmetricGroupRepresentations_class(CombinatorialClass):
             True
         """
         self._n = n
-        self._ring = ring if not ring is None else self._default_ring
+        self._ring = ring if ring is not None else self._default_ring
         self._cache_matrices = cache_matrices
+        Parent.__init__(self, category=FiniteEnumeratedSets())
 
-    def __call__(self, partition):
+    def _element_constructor_(self, partition):
         r"""
-        Return the irreducible representation corresponding to partition.
+        Return the irreducible representation corresponding to ``partition``.
 
         EXAMPLES::
 
@@ -474,8 +492,19 @@ class SymmetricGroupRepresentations_class(CombinatorialClass):
         """
         if Partition(partition).size() != self._n:
             raise TypeError("not a partition of %s" % self._n)
-        return self.object_class(partition, ring=self._ring,
-                cache_matrices=self._cache_matrices)
+        return self.element_class(self, partition)
+
+    def cardinality(self):
+        """
+        Return the cardinality of ``self``.
+
+        EXAMPLES::
+
+            sage: sp = SymmetricGroupRepresentations(4, "specht")
+            sage: sp.cardinality()
+            5
+        """
+        return Partitions(self._n).cardinality()
 
     def __iter__(self):
         r"""
@@ -491,10 +520,10 @@ class SymmetricGroupRepresentations_class(CombinatorialClass):
             Orthogonal representation of the symmetric group corresponding to [1, 1, 1]
         """
         for partition in Partitions(self._n):
-            yield self.object_class(partition, ring=self._ring,
-                    cache_matrices=self._cache_matrices)
+            yield self.element_class(self, partition)
+
+# #### Young's Seminormal Representation ###################################
 
-##### Young's Seminormal Representation ###################################
 
 class YoungRepresentation_generic(SymmetricGroupRepresentation_generic_class):
     r"""
@@ -513,15 +542,15 @@ class YoungRepresentation_generic(SymmetricGroupRepresentation_generic_class):
             Yang-Baxter graph of [3, 2], with top vertex (0, -1, 2, 1, 0)
         """
         Y = YangBaxterGraph_partition(self._partition)
-        n = self._partition.size()
+        n = self._n
         # relabel vertices with "vector of contents"
-        Y.relabel_vertices(\
-            partition_to_vector_of_contents(self._partition, reverse=True))
+        Y.relabel_vertices(partition_to_vector_of_contents(self._partition,
+                                                           reverse=True))
         # relabel edges with "differences"
         edge_relabel_dict = {}
-        for (u,v,op) in Y.edges():
-            i = op.position()+1
-            edge_relabel_dict[u,v] = (n-i,QQ((1,u[i]-u[i-1])))
+        for u, v, op in Y.edges():
+            i = op.position() + 1
+            edge_relabel_dict[u, v] = (n - i, QQ((1, u[i] - u[i - 1])))
         Y.relabel_edges(edge_relabel_dict)
         return Y
 
@@ -543,11 +572,12 @@ class YoungRepresentation_generic(SymmetricGroupRepresentation_generic_class):
         """
         # construct a dictionary pairing vertices with tableau
         t = StandardTableaux(self._partition).last()
-        tableau_dict = {self._yang_baxter_graph.root():t}
-        for (u,w,(i,beta)) in self._yang_baxter_graph._edges_in_bfs():
+        tableau_dict = {self._yang_baxter_graph.root(): t}
+        for (u, w, (i, beta)) in self._yang_baxter_graph._edges_in_bfs():
             # TODO: improve the following
-            si = PermutationConstructor((i,i+1))
-            tableau_dict[w] = Tableau([[si(_) for _ in row] for row in tableau_dict[u]])
+            si = PermutationConstructor((i, i + 1))
+            tableau_dict[w] = Tableau([[si(b) for b in row]
+                                       for row in tableau_dict[u]])
         return tableau_dict
 
     @lazy_attribute
@@ -566,10 +596,8 @@ class YoungRepresentation_generic(SymmetricGroupRepresentation_generic_class):
              (2, 0, -1, 1, 0): (3, 4, 1, 2, 5),
              (2, 0, 1, -1, 0): (2, 4, 1, 3, 5)}
         """
-        word_dict = {}
-        for (v,t) in self._tableau_dict.items():
-            word_dict[v] = sum(reversed(t), ())
-        return word_dict
+        return {v: sum(reversed(t), ())
+                for v, t in self._tableau_dict.items()}
 
     @cached_method
     def representation_matrix_for_simple_transposition(self, i):
@@ -599,31 +627,31 @@ class YoungRepresentation_generic(SymmetricGroupRepresentation_generic_class):
         if not(1 <= i < sum(self._partition)):
             raise TypeError
         Y = self._yang_baxter_graph
-        index_lookup = dict((b,a) for (a,b) in enumerate(list(Y)))
+        index_lookup = {b: a for a, b in enumerate(list(Y))}
         digraph = copy(Y._digraph)
-        digraph.delete_edges((u,v) for (u,v,(j,beta))
-                in digraph.edges() if j != i)
+        digraph.delete_edges((u, v) for (u, v, (j, beta)) in digraph.edges()
+                             if j != i)
         M = matrix(self._ring, digraph.num_verts())
         for g in digraph.connected_components_subgraphs():
             if g.num_verts() == 1:
                 [v] = g.vertices()
                 w = self._word_dict[v]
                 trivial = None
-                for (j, a) in enumerate(w):
-                    if a == i and w[j+1]==i+1:
+                for j, a in enumerate(w):
+                    if a == i and w[j + 1] == i + 1:
                         trivial = True
                         break
-                    elif a == i+1:
+                    elif a == i + 1:
                         trivial = False
                         break
                 j = index_lookup[v]
-                M[j,j] = 1 if trivial is True else -1
+                M[j, j] = 1 if trivial is True else -1
             else:
-                [(u,v,(j,beta))] = g.edges()
+                [(u, v, (j, beta))] = g.edges()
                 iu = index_lookup[u]
                 iv = index_lookup[v]
-                M[iu,iu], M[iu,iv], M[iv,iu], M[iv,iv] = \
-                        self._2x2_matrix_entries(beta)
+                M[iu, iu], M[iu, iv], M[iv, iu], M[iv, iv] = \
+                    self._2x2_matrix_entries(beta)
         return M
 
     def _representation_matrix_uncached(self, permutation):
@@ -685,124 +713,124 @@ class YoungRepresentation_generic(SymmetricGroupRepresentation_generic_class):
             [-1/2  3/2]
             [ 1/2  1/2]
         """
-        return self._representation_matrix_uncached(permutation)
+        ret = self._representation_matrix_uncached(permutation)
+        ret.set_immutable()
+        return ret
+
 
 class YoungRepresentation_Seminormal(YoungRepresentation_generic):
-    _default_ring = QQ
-
-    def __repr__(self):
+    def _repr_(self):
         r"""
         String representation of ``self``.
 
         EXAMPLES::
 
-            sage: from sage.combinat.symmetric_group_representations import YoungRepresentation_Seminormal
-            sage: YoungRepresentation_Seminormal([2,1]).__repr__()
-            'Seminormal representation of the symmetric group corresponding to [2, 1]'
+            sage: SymmetricGroupRepresentation([2,1], "seminormal")
+            Seminormal representation of the symmetric group corresponding to [2, 1]
         """
-        return "Seminormal representation of the symmetric group corresponding to %s" % self._partition
+        return "Seminormal representation of the symmetric group corresponding to {}".format(self._partition)
 
     def _2x2_matrix_entries(self, beta):
         r"""
         Young's representations are constructed by combining
-        `2\times2`-matrices that depend on ``beta``. For the seminormal
-        representation, this is the following matrix.:
+        `2 \times 2`-matrices that depend on ``beta``.
 
-            ``[  -beta     1+beta ]``
-            ``[ 1-beta      beta  ]``
+        For the seminormal representation, this is the following matrix::
+
+            [  -beta     1+beta ]
+            [ 1-beta      beta  ]
 
         EXAMPLES::
 
-            sage: from sage.combinat.symmetric_group_representations import YoungRepresentation_Seminormal
-            sage: snorm = YoungRepresentation_Seminormal([2,1])
+            sage: snorm = SymmetricGroupRepresentation([2,1], "seminormal")
             sage: snorm._2x2_matrix_entries(1/2)
             (-1/2, 3/2, 1/2, 1/2)
         """
-        return (-beta, 1+beta, 1-beta, beta)
+        return (-beta, 1 + beta, 1 - beta, beta)
+
 
 class YoungRepresentations_Seminormal(SymmetricGroupRepresentations_class):
     _default_ring = QQ
 
-    object_class = YoungRepresentation_Seminormal
+    Element = YoungRepresentation_Seminormal
 
-    def __repr__(self):
+    def _repr_(self):
         r"""
-        String representation of self.
+        String representation of ``self``.
 
         EXAMPLES::
 
             sage: from sage.combinat.symmetric_group_representations import YoungRepresentations_Seminormal
-            sage: YoungRepresentations_Seminormal(3).__repr__()
-            'Seminormal representations of the symmetric group of order 3! over Rational Field'
+            sage: YoungRepresentations_Seminormal(3)
+            Seminormal representations of the symmetric group of order 3! over Rational Field
         """
         return "Seminormal representations of the symmetric group of order %s! over %s" % (self._n, self._ring)
 
-##### Young's Orthogonal Representation ###################################
+# #### Young's Orthogonal Representation ###################################
+
 
 class YoungRepresentation_Orthogonal(YoungRepresentation_generic):
-    _default_ring = SR
-
-    def __repr__(self):
+    def _repr_(self):
         r"""
-        String representation of self.
+        String representation of ``self``.
 
         EXAMPLES::
 
-            sage: from sage.combinat.symmetric_group_representations import YoungRepresentation_Orthogonal
-            sage: YoungRepresentation_Orthogonal([2,1]).__repr__()
-            'Orthogonal representation of the symmetric group corresponding to [2, 1]'
+            sage: SymmetricGroupRepresentation([2,1], "orthogonal")
+            Orthogonal representation of the symmetric group corresponding to [2, 1]
         """
-        return "Orthogonal representation of the symmetric group corresponding to %s" % self._partition
+        return "Orthogonal representation of the symmetric group corresponding to {}".format(self._partition)
 
     def _2x2_matrix_entries(self, beta):
         r"""
         Young's representations are constructed by combining
-        `2\times2`-matrices that depend on ``beta`` For the orthogonal
-        representation, this is the following matrix::
+        `2 \times 2`-matrices that depend on ``beta``.
 
-            ``[     -beta       sqrt(1-beta^2) ]``
-            ``[ sqrt(1-beta^2)       beta      ]``
+        For the orthogonal representation, this is the following matrix::
+
+            [     -beta       sqrt(1-beta^2) ]
+            [ sqrt(1-beta^2)       beta      ]
 
         EXAMPLES::
 
-            sage: from sage.combinat.symmetric_group_representations import YoungRepresentation_Orthogonal
-            sage: orth = YoungRepresentation_Orthogonal([2,1])
+            sage: orth = SymmetricGroupRepresentation([2,1], "orthogonal")
             sage: orth._2x2_matrix_entries(1/2)
             (-1/2, 1/2*sqrt(3), 1/2*sqrt(3), 1/2)
         """
-        return (-beta, sqrt(1-beta**2), sqrt(1-beta**2), beta)
+        return (-beta, sqrt(1 - beta**2), sqrt(1 - beta**2), beta)
+
 
 class YoungRepresentations_Orthogonal(SymmetricGroupRepresentations_class):
     _default_ring = SR
 
-    object_class = YoungRepresentation_Orthogonal
+    Element = YoungRepresentation_Orthogonal
 
-    def __repr__(self):
+    def _repr_(self):
         r"""
         String representation of ``self``.
 
         EXAMPLES::
 
             sage: from sage.combinat.symmetric_group_representations import YoungRepresentations_Orthogonal
-            sage: YoungRepresentations_Orthogonal(3).__repr__()
-            'Orthogonal representations of the symmetric group of order 3! over Symbolic Ring'
+            sage: YoungRepresentations_Orthogonal(3)
+            Orthogonal representations of the symmetric group of order 3! over Symbolic Ring
         """
         return "Orthogonal representations of the symmetric group of order %s! over %s" % (self._n, self._ring)
 
-##### Specht Representation ###############################################
+# #### Specht Representation ###############################################
+
 
 class SpechtRepresentation(SymmetricGroupRepresentation_generic_class):
-    def __repr__(self):
+    def _repr_(self):
         r"""
         String representation of ``self``.
 
         EXAMPLES::
 
-            sage: from sage.combinat.symmetric_group_representations import SpechtRepresentation
-            sage: SpechtRepresentation([2,1]).__repr__()
-            'Specht representation of the symmetric group corresponding to [2, 1]'
+            sage: SymmetricGroupRepresentation([2,1], "specht")
+            Specht representation of the symmetric group corresponding to [2, 1]
         """
-        return "Specht representation of the symmetric group corresponding to %s" % self._partition
+        return "Specht representation of the symmetric group corresponding to {}".format(self._partition)
 
     _default_ring = ZZ
 
@@ -832,7 +860,7 @@ class SpechtRepresentation(SymmetricGroupRepresentation_generic_class):
             [(3, 3, 0, 0, 0), (3, 0, 3, 0, 0), (3, 0, 0, 3, 0), (0, 3, 3, 0, 0), (0, 3, 0, 3, 0)]
         """
         top = self._yang_baxter_graph.root()
-        exponents = tuple(i-x for (i,x) in enumerate(reversed(top)))[::-1]
+        exponents = tuple(i - x for i, x in enumerate(reversed(top)))[::-1]
         relabelling = self._yang_baxter_graph.vertex_relabelling_dict(exponents)
         return [relabelling[u] for u in self._yang_baxter_graph]
 
@@ -854,7 +882,7 @@ class SpechtRepresentation(SymmetricGroupRepresentation_generic_class):
             sage: spc.scalar_product((1,0,2,1,0),(3,0,0,3,0))
             0
         """
-        uv = [a + v[i] + 1 for (i,a) in enumerate(u)]
+        uv = [a + v[i] + 1 for i, a in enumerate(u)]
         if uv not in Permutations():
             return 0
         else:
@@ -877,11 +905,11 @@ class SpechtRepresentation(SymmetricGroupRepresentation_generic_class):
             [ 0  0  1]
         """
         if permutation is None:
-            permutation = Permutation(range(1,1+self._partition.size()))
+            permutation = Permutation(range(1, 1 + self._n))
         Q = matrix(QQ, len(self._yang_baxter_graph))
-        for (i,v) in enumerate(self._dual_vertices):
-            for (j,u) in enumerate(self._yang_baxter_graph):
-                Q[i,j] = self.scalar_product(tuple(permutation.action(v)), u)
+        for i, v in enumerate(self._dual_vertices):
+            for j, u in enumerate(self._yang_baxter_graph):
+                Q[i, j] = self.scalar_product(tuple(permutation.action(v)), u)
         return Q
 
     @lazy_attribute
@@ -902,7 +930,7 @@ class SpechtRepresentation(SymmetricGroupRepresentation_generic_class):
     @cached_method
     def representation_matrix(self, permutation):
         r"""
-        Returns the matrix representing the ``permutation`` in this
+        Return the matrix representing the ``permutation`` in this
         irreducible representation.
 
         .. NOTE::
@@ -921,11 +949,13 @@ class SpechtRepresentation(SymmetricGroupRepresentation_generic_class):
             [0 1 0]
             [1 0 0]
         """
-        return self._representation_matrix_uncached(permutation)
+        ret = self._representation_matrix_uncached(permutation)
+        ret.set_immutable()
+        return ret 
 
     def _representation_matrix_uncached(self, permutation):
         r"""
-        Returns the matrix representing the ``permutation`` in this
+        Return the matrix representing the ``permutation`` in this
         irreducible representation.
 
         EXAMPLES::
@@ -943,28 +973,30 @@ class SpechtRepresentation(SymmetricGroupRepresentation_generic_class):
         R = self.scalar_product_matrix(permutation)
         return self._scalar_product_matrix_inverse * R
 
-class SpechtRepresentations(SymmetricGroupRepresentations_class):
-    object_class = SpechtRepresentation
 
+class SpechtRepresentations(SymmetricGroupRepresentations_class):
     _default_ring = ZZ
 
-    def __repr__(self):
+    Element = SpechtRepresentation
+
+    def _repr_(self):
         r"""
         String representation of ``self``.
 
         EXAMPLES::
 
             sage: spc = SymmetricGroupRepresentations(4)
-            sage: spc.__repr__()
-            'Specht representations of the symmetric group of order 4! over Integer Ring'
+            sage: spc
+            Specht representations of the symmetric group of order 4! over Integer Ring
         """
         return "Specht representations of the symmetric group of order %s! over %s" % (self._n, self._ring)
 
-###### Miscellaneous functions ############################################
+# ##### Miscellaneous functions ############################################
+
 
 def partition_to_vector_of_contents(partition, reverse=False):
     r"""
-    Returns the "vector of contents" associated to ``partition``.
+    Return the "vector of contents" associated to ``partition``.
 
     EXAMPLES::
 
@@ -973,8 +1005,9 @@ def partition_to_vector_of_contents(partition, reverse=False):
         (0, 1, 2, -1, 0)
     """
     v = []
-    for (i,p) in enumerate(partition):
-        v.extend(range(-i,-i+p))
+    for i, p in enumerate(partition):
+        v.extend(range(-i, -i + p))
     if reverse:
         return tuple(v)[::-1]
     return tuple(v)
+
