@@ -363,8 +363,8 @@ def _create_print_table(cur, col_titles, **kwds):
                         + '</td>\n'
                     p += 1
                 else:
-                    raise NotImplementedError('Cannot display plot on ' \
-                        + 'command line.')
+                    raise NotImplementedError('Cannot display plot on '
+                                              'command line.')
             else:
                 if index in fcol_index:
                     if id_col_index is None:
@@ -382,8 +382,7 @@ def _create_print_table(cur, col_titles, **kwds):
             cur_str.append(field_val)
         return ' '.join(cur_str)
 
-    from sage.server.support import EMBEDDED_MODE
-    if EMBEDDED_MODE or ('html_table' in kwds and kwds['html_table']):
+    if 'html_table' in kwds and kwds['html_table']:
         # Notebook Version
         ret = '<html><!--notruncate-->\n'
         ret += '  <table bgcolor=lightgrey cellpadding=0>\n'
@@ -672,7 +671,8 @@ class SQLQuery(SageObject):
             C^                   [2, 2, 3, 3]
             C~                   [3, 3, 3, 3]
         """
-        if not self.__query_string__: return self.__database__.show()
+        if not self.__query_string__:
+            return self.__database__.show()
 
         try:
             cur = self.__database__.__connection__.cursor()
@@ -761,13 +761,16 @@ class SQLQuery(SageObject):
             if not self.__query_string__:
                 self.__query_string__ = other.__query_string__
                 self.__param_tuple__ = other.__param_tuple__
-            elif not other.__query_string__: return
+            elif not other.__query_string__:
+                return
             else:
                 self._merge_queries(other, self, join_table, join_dict, 'AND')
         else:
             from copy import copy
-            if not self.__query_string__: return copy(other)
-            if not other.__query_string__: return copy(self)
+            if not self.__query_string__:
+                return copy(other)
+            if not other.__query_string__:
+                return copy(self)
             return self._merge_queries(other, copy(self), join_table, \
                 join_dict, 'AND')
 
@@ -882,8 +885,10 @@ class SQLQuery(SageObject):
                 self._merge_queries(other, self, join_table, join_dict, 'OR')
         else:
             from copy import copy
-            if not self.__query_string__: return copy(self)
-            if not other.__query_string__: return copy(other)
+            if not self.__query_string__:
+                return copy(self)
+            if not other.__query_string__:
+                return copy(other)
             return self._merge_queries(other, copy(self), join_table, \
                 join_dict, 'OR')
 
@@ -1478,7 +1483,7 @@ class SQLDatabase(SageObject):
                       as primary key
                     - ``index`` -- boolean, whether column has been set as
                       index
-                    - ``unique`` -- boolean, weather column has been set as
+                    - ``unique`` -- boolean, whether column has been set as
                       unique
                     - ``sql`` -- one of ``'TEXT'``, ``'BOOLEAN'``,
                       ``'INTEGER'``, ``'REAL'``, or other user defined type
@@ -1637,7 +1642,8 @@ class SQLDatabase(SageObject):
             self.__skeleton__[table_name] if \
             self.__skeleton__[table_name][col]['index'] and not \
             self.__skeleton__[table_name][col]['primary_key']])
-        if index_statement: self.__connection__.executescript(index_statement)
+        if index_statement:
+            self.__connection__.executescript(index_statement)
 
         # Now we can plop our data into the *new* table:
         self.__connection__.executescript("""
