@@ -7,22 +7,22 @@ These functions wait to evaluate if there are variables.
 
 Here you can see some differences::
 
-   sage: max(x,x^2)
+   sage: max(x, x^2)
    x
-   sage: max_symbolic(x,x^2)
+   sage: max_symbolic(x, x^2)
    max(x, x^2)
-   sage: f(x) = max_symbolic(x,x^2); f(1/2)
+   sage: f(x) = max_symbolic(x, x^2); f(1/2)
    1/2
 
 This works as expected for more than two entries::
 
-   sage: max(3,5,x)
+   sage: max(3, 5, x)
    5
-   sage: min(3,5,x)
+   sage: min(3, 5, x)
    3
-   sage: max_symbolic(3,5,x)
+   sage: max_symbolic(3, 5, x)
    max(x, 5)
-   sage: min_symbolic(3,5,x)
+   sage: min_symbolic(3, 5, x)
    min(x, 3)
 
 """
@@ -33,7 +33,6 @@ This works as expected for more than two entries::
 #  version 2 or any later version.  The full text of the GPL is available at:
 #                  http://www.gnu.org/licenses/
 ###############################################################################
-from __future__ import absolute_import
 
 from sage.symbolic.function import BuiltinFunction
 from sage.symbolic.expression import Expression
@@ -46,10 +45,15 @@ class MinMax_base(BuiltinFunction):
         """
         EXAMPLES::
 
-            sage: max_symbolic(3,5,x) # indirect doctest
+            sage: max_symbolic(3, 5, x)  # indirect doctest
             max(x, 5)
-            sage: min_symbolic(3,5,x)
+            sage: max_symbolic([5.0r])   # indirect doctest
+            5.0
+            sage: min_symbolic(3, 5, x)
             min(x, 3)
+            sage: min_symbolic([5.0r])   # indirect doctest
+            5.0
+
         """
         # __call__ ensures that if args is a singleton, the element is iterable
         arg_is_iter = False
@@ -66,49 +70,40 @@ class MinMax_base(BuiltinFunction):
             else:
                 num_non_symbolic_args += 1
                 if res is None:
-                    # Any argument is greater or less than None
                     res = x
                 else:
                     res = builtin_f(res, x)
 
         # if no symbolic arguments, return the result
         if len(symb_args) == 0:
-            if res is None:
-                # this is a hack to get the function to return None to the user
-                # the convention to leave a given symbolic function unevaluated
-                # is to return None from the _eval_ function, so we need
-                # a trick to indicate that the return value of the function is
-                # really None
-                # this is caught in the __call__ method, which knows to return
-                # None in this case
-                raise ValueError("return None")
             return res
 
         # if all arguments were symbolic return
         if num_non_symbolic_args <= 1 and not arg_is_iter:
             return None
 
-        if res is not None: symb_args.append(res)
+        if res is not None:
+            symb_args.append(res)
         return this_f(*symb_args)
 
     def __call__(self, *args, **kwds):
         """
         EXAMPLES::
 
-            sage: max_symbolic(3,5,x)
+            sage: max_symbolic(3, 5, x)
             max(x, 5)
-            sage: max_symbolic(3,5,x, hold=True)
+            sage: max_symbolic(3, 5, x, hold=True)
             max(3, 5, x)
-            sage: max_symbolic([3,5,x])
+            sage: max_symbolic([3, 5, x])
             max(x, 5)
 
         ::
 
-            sage: min_symbolic(3,5,x)
+            sage: min_symbolic(3, 5, x)
             min(x, 3)
-            sage: min_symbolic(3,5,x, hold=True)
+            sage: min_symbolic(3, 5, x, hold=True)
             min(3, 5, x)
-            sage: min_symbolic([3,5,x])
+            sage: min_symbolic([3, 5, x])
             min(x, 3)
 
         TESTS:
@@ -120,17 +115,6 @@ class MinMax_base(BuiltinFunction):
             ...
             ValueError: number of arguments must be > 0
 
-        Check if we return None, when the builtin function would::
-
-            sage: max_symbolic([None]) is None  # py2 on Python 3 None is not ordered
-            True
-            sage: max_symbolic([None, None]) is None  # py2
-            True
-            sage: min_symbolic([None]) is None  # py2
-            True
-            sage: min_symbolic([None, None]) is None  # py2
-            True
-
         Check if a single argument which is not iterable works::
 
             sage: max_symbolic(None)
@@ -159,15 +143,13 @@ class MinMax_base(BuiltinFunction):
         if len(args) == 1:
             try:
                 args = (SR._force_pyobject(iter(args[0])),)
-            except TypeError as e:
-                raise e
+            except TypeError:
+                raise
 
         try:
             return BuiltinFunction.__call__(self, *args, **kwds)
-        except ValueError as e:
-            if e.args[0] == "return None":
-                return None
-
+        except ValueError:
+            pass
 
 class MaxSymbolic(MinMax_base):
     def __init__(self):
@@ -186,14 +168,14 @@ class MaxSymbolic(MinMax_base):
             5
             sage: max_symbolic(3, 5, x)
             max(x, 5)
-            sage: max_symbolic([3,5,x])
+            sage: max_symbolic([3, 5, x])
             max(x, 5)
 
         TESTS::
 
-            sage: loads(dumps(max_symbolic(x,5)))
+            sage: loads(dumps(max_symbolic(x, 5)))
             max(x, 5)
-            sage: latex(max_symbolic(x,5))
+            sage: latex(max_symbolic(x, 5))
             \max\left(x, 5\right)
             sage: max_symbolic(x, 5)._sympy_()
             Max(5, x)
@@ -207,17 +189,17 @@ class MaxSymbolic(MinMax_base):
 
             sage: t = max_symbolic(x, 5); t
             max(x, 5)
-            sage: t.subs(x=3) # indirect doctest
+            sage: t.subs(x=3)  # indirect doctest
             5
-            sage: max_symbolic(5,3)
+            sage: max_symbolic(5, 3)
             5
-            sage: u = max_symbolic(*(list(range(10))+[x])); u
+            sage: u = max_symbolic(*(list(range(10)) + [x])); u
             max(x, 9)
             sage: u.subs(x=-1)
             9
             sage: u.subs(x=10)
             10
-            sage: max_symbolic([0,x])
+            sage: max_symbolic([0, x])
             max(x, 0)
 
         TESTS::
@@ -277,14 +259,14 @@ class MinSymbolic(MinMax_base):
             3
             sage: min_symbolic(3, 5, x)
             min(x, 3)
-            sage: min_symbolic([3,5,x])
+            sage: min_symbolic([3, 5, x])
             min(x, 3)
 
         TESTS::
 
-            sage: loads(dumps(min_symbolic(x,5)))
+            sage: loads(dumps(min_symbolic(x, 5)))
             min(x, 5)
-            sage: latex(min_symbolic(x,5))
+            sage: latex(min_symbolic(x, 5))
             \min\left(x, 5\right)
             sage: min_symbolic(x, 5)._sympy_()
             Min(5, x)
@@ -298,17 +280,17 @@ class MinSymbolic(MinMax_base):
 
             sage: t = min_symbolic(x, 5); t
             min(x, 5)
-            sage: t.subs(x=3) # indirect doctest
+            sage: t.subs(x=3)  # indirect doctest
             3
-            sage: min_symbolic(5,3)
+            sage: min_symbolic(5, 3)
             3
-            sage: u = min_symbolic(*(list(range(10))+[x])); u
+            sage: u = min_symbolic(*(list(range(10)) + [x])); u
             min(x, 0)
             sage: u.subs(x=-1)
             -1
             sage: u.subs(x=10)
             0
-            sage: min_symbolic([3,x])
+            sage: min_symbolic([3, x])
             min(x, 3)
 
         TESTS::
