@@ -10,8 +10,6 @@ Generate cdd ``.ext`` / ``.ine`` file format
 #
 #                  http://www.gnu.org/licenses/
 ########################################################################
-from __future__ import print_function
-from __future__ import absolute_import
 
 from .misc import _set_to_None_if_empty, _common_length_of, _to_space_separated_string
 
