@@ -72,19 +72,17 @@ polyhedron with the :meth:`PolyhedronFace.as_polyhedron` method::
 #
 #                  http://www.gnu.org/licenses/
 ########################################################################
-from __future__ import print_function
 
-from sage.structure.sage_object import SageObject
 from sage.structure.richcmp import richcmp_method, richcmp
-from sage.misc.all import cached_method
+from sage.misc.cachefunc import cached_method
 from sage.modules.free_module_element import vector
 from sage.matrix.constructor import matrix
-
+from sage.geometry.convex_set import ConvexSet_closed
 
 
 #########################################################################
 @richcmp_method
-class PolyhedronFace(SageObject):
+class PolyhedronFace(ConvexSet_closed):
     r"""
     A face of a polyhedron.
 
@@ -122,6 +120,10 @@ class PolyhedronFace(SageObject):
         (An inequality (1, 1, 1) x + 1 >= 0,)
         sage: face.ambient_Vrepresentation()
         (A vertex at (-1, 0, 0), A vertex at (0, -1, 0), A vertex at (0, 0, -1))
+
+    TESTS::
+
+        sage: TestSuite(face).run()
     """
 
     def __init__(self, polyhedron, V_indices, H_indices):
@@ -148,12 +150,15 @@ class PolyhedronFace(SageObject):
             sage: from sage.geometry.polyhedron.face import PolyhedronFace
             sage: PolyhedronFace(Polyhedron(), [], [])   # indirect doctest
             A -1-dimensional face of a Polyhedron in ZZ^0
+            sage: TestSuite(_).run(skip='_test_pickling')
         """
         self._polyhedron = polyhedron
         self._ambient_Vrepresentation_indices = tuple(V_indices)
         self._ambient_Hrepresentation_indices = tuple(H_indices)
         self._ambient_Vrepresentation = tuple( polyhedron.Vrepresentation(i) for i in V_indices )
         self._ambient_Hrepresentation = tuple( polyhedron.Hrepresentation(i) for i in H_indices )
+        if polyhedron.is_mutable():
+            polyhedron._add_dependent_object(self)
 
     def __hash__(self):
         r"""
@@ -181,6 +186,10 @@ class PolyhedronFace(SageObject):
             A vertex at (1, 1)
             sage: type(face.vertex_generator())
             <... 'generator'>
+
+        TESTS::
+
+            sage: TestSuite(face).run(skip='_test_pickling')
         """
         for V in self.ambient_Vrepresentation():
             if V.is_vertex():
@@ -201,6 +210,10 @@ class PolyhedronFace(SageObject):
             sage: face = triangle.faces(1)[2]
             sage: face.vertices()
             (A vertex at (0, 1), A vertex at (1, 0))
+
+        TESTS::
+
+            sage: TestSuite(face).run(skip='_test_pickling')
         """
         return tuple(self.vertex_generator())
 
@@ -219,6 +232,10 @@ class PolyhedronFace(SageObject):
             sage: face = Q.faces(2)[0]
             sage: face.n_vertices()
             3
+
+        TESTS::
+
+            sage: TestSuite(face).run(skip='_test_pickling')
         """
         return len(self.vertices())
 
@@ -232,6 +249,10 @@ class PolyhedronFace(SageObject):
             sage: face = pi.faces(1)[1]
             sage: next(face.ray_generator())
             A ray in the direction (1, 0)
+
+        TESTS::
+
+            sage: TestSuite(face).run(skip='_test_pickling')
         """
         for V in self.ambient_Vrepresentation():
             if V.is_ray():
@@ -283,6 +304,10 @@ class PolyhedronFace(SageObject):
             sage: face = pr.faces(1)[0]
             sage: next(face.line_generator())
             A line in the direction (1, 0)
+
+        TESTS::
+
+            sage: TestSuite(face).run(skip='_test_pickling')
         """
         for V in self.ambient_Vrepresentation():
             if V.is_line():
@@ -351,7 +376,9 @@ class PolyhedronFace(SageObject):
         if not isinstance(other, PolyhedronFace):
             return NotImplemented
         if self._polyhedron is not other._polyhedron:
-            return NotImplemented
+            if (self._polyhedron.Vrepresentation() != other._polyhedron.Vrepresentation()
+                    or self._polyhedron.Hrepresentation() != other._polyhedron.Hrepresentation()):
+                return NotImplemented
         return richcmp(self._ambient_Vrepresentation_indices,
                        other._ambient_Vrepresentation_indices, op)
 
@@ -615,22 +642,32 @@ class PolyhedronFace(SageObject):
         if self.n_vertices() > 0:
             desc += ' defined as the convex hull of '
             desc += repr(self.n_vertices())
-            if self.n_vertices() == 1: desc += ' vertex'
-            else:                      desc += ' vertices'
+            if self.n_vertices() == 1:
+                desc += ' vertex'
+            else:
+                desc += ' vertices'
 
             if self.n_rays() > 0:
-                if self.n_lines() > 0: desc += ", "
-                else:                  desc += " and "
+                if self.n_lines() > 0:
+                    desc += ", "
+                else:
+                    desc += " and "
                 desc += repr(self.n_rays())
-                if self.n_rays() == 1: desc += ' ray'
-                else:                  desc += ' rays'
+                if self.n_rays() == 1:
+                    desc += ' ray'
+                else:
+                    desc += ' rays'
 
             if self.n_lines() > 0:
-                if self.n_rays() > 0: desc += ", "
-                else:                 desc += " and "
+                if self.n_rays() > 0:
+                    desc += ", "
+                else:
+                    desc += " and "
                 desc += repr(self.n_lines())
-                if self.n_lines() == 1: desc += ' line'
-                else:                   desc += ' lines'
+                if self.n_lines() == 1:
+                    desc += ' line'
+                else:
+                    desc += ' lines'
 
         return desc
 
@@ -650,6 +687,68 @@ class PolyhedronFace(SageObject):
         """
         return self._polyhedron
 
+    ambient = polyhedron
+
+    def ambient_vector_space(self, base_field=None):
+        r"""
+        Return the ambient vector space.
+
+        It is the ambient free module of the containing polyhedron tensored
+        with a field.
+
+        INPUT:
+
+        - ``base_field`` -- (default: the fraction field of the base ring) a field.
+
+        EXAMPLES::
+
+            sage: half_plane = Polyhedron(ieqs=[(0,1,0)])
+            sage: line = half_plane.faces(1)[0]; line
+            A 1-dimensional face of a Polyhedron in QQ^2 defined as the convex hull of 1 vertex and 1 line
+            sage: line.ambient_vector_space()
+            Vector space of dimension 2 over Rational Field
+            sage: line.ambient_vector_space(AA)
+            Vector space of dimension 2 over Algebraic Real Field
+        """
+        return self.polyhedron().ambient_vector_space(base_field=base_field)
+
+    def is_relatively_open(self):
+        r"""
+        Return whether ``self`` is relatively open.
+
+        OUTPUT:
+
+        Boolean.
+
+        EXAMPLES::
+
+            sage: half_plane = Polyhedron(ieqs=[(0,1,0)])
+            sage: line = half_plane.faces(1)[0]; line
+            A 1-dimensional face of a Polyhedron in QQ^2 defined as the convex hull of 1 vertex and 1 line
+            sage: line.is_relatively_open()
+            True
+        """
+        return self.as_polyhedron().is_relatively_open()
+
+    def is_compact(self):
+        r"""
+        Return whether ``self`` is compact.
+
+        OUTPUT:
+
+        Boolean.
+
+        EXAMPLES::
+
+            sage: half_plane = Polyhedron(ieqs=[(0,1,0)])
+            sage: line = half_plane.faces(1)[0]; line
+            A 1-dimensional face of a Polyhedron in QQ^2 defined as the convex hull of 1 vertex and 1 line
+            sage: line.is_compact()
+            False
+        """
+        return not any(V.is_ray() or V.is_line()
+                       for V in self.ambient_Vrepresentation())
+
     @cached_method
     def as_polyhedron(self):
         """
@@ -677,10 +776,75 @@ class PolyhedronFace(SageObject):
         Vrep = (self.vertices(), self.rays(), self.lines())
         return P.__class__(parent, Vrep, None)
 
+    def _some_elements_(self):
+        r"""
+        Generate some points of ``self``.
+
+        If ``self`` is empty, no points are generated; no exception will be raised.
+
+        EXAMPLES::
+
+            sage: P = polytopes.cross_polytope(3);  P
+            A 3-dimensional polyhedron in ZZ^3 defined as the convex hull of 6 vertices
+            sage: face = P.faces(2)[3]
+            sage: face
+            A 2-dimensional face of a Polyhedron in ZZ^3 defined as the convex hull of 3 vertices
+            sage: face.as_polyhedron().vertices()
+            (A vertex at (0, -1, 0), A vertex at (0, 0, -1), A vertex at (1, 0, 0))
+            sage: face.an_element()              # indirect doctest
+            (1/3, -1/3, -1/3)
+            sage: face.some_elements()           # indirect doctest
+            [(1/3, -1/3, -1/3), (0, -1, 0), (0, -1/2, -1/2), (1/2, -1/4, -1/4)]
+        """
+        yield from self.as_polyhedron().some_elements()
+
+    def contains(self, point):
+        """
+        Test whether the polyhedron contains the given ``point``.
+
+        INPUT:
+
+        - ``point`` -- a point or its coordinates
+
+        EXAMPLES::
+
+            sage: half_plane = Polyhedron(ieqs=[(0,1,0)])
+            sage: line = half_plane.faces(1)[0]; line
+            A 1-dimensional face of a Polyhedron in QQ^2 defined as the convex hull of 1 vertex and 1 line
+            sage: line.contains([0, 1])
+            True
+
+        As a shorthand, one may use the usual ``in`` operator::
+
+            sage: [5, 7] in line
+            False
+        """
+        # preprocess in the same way as Polyhedron_base.contains
+        try:
+            p = vector(point)
+        except TypeError:  # point not iterable or no common ring for elements
+            if len(point) > 0:
+                return False
+            else:
+                p = vector(self.polyhedron().base_ring(), [])
+
+        if len(p) != self.ambient_dim():
+            return False
+
+        if not self.polyhedron().contains(p):
+            return False
+
+        for H in self.ambient_Hrepresentation():
+            if H.eval(p) != 0:
+                return False
+        return True
+
+    __contains__ = contains
+
     @cached_method
     def normal_cone(self, direction='outer'):
         """
-        Return the pointed polyhedral cone consisting of normal vectors to
+        Return the polyhedral cone consisting of normal vectors to
         hyperplanes supporting ``self``.
 
         INPUT:
@@ -756,6 +920,95 @@ class PolyhedronFace(SageObject):
         origin = self.polyhedron().ambient_space().zero()
         return parent.element_class(parent, [[origin], rays, lines], None)
 
+    @cached_method
+    def affine_tangent_cone(self):
+        """
+        Return the affine tangent cone of ``self`` as a polyhedron.
+
+        It is equal to the sum of ``self`` and the cone of feasible directions
+        at any point of the relative interior of ``self``.
+
+        OUTPUT:
+
+        A polyhedron.
+
+        EXAMPLES::
+
+            sage: half_plane_in_space = Polyhedron(ieqs=[(0,1,0,0)], eqns=[(0,0,0,1)])
+            sage: line = half_plane_in_space.faces(1)[0]; line
+            A 1-dimensional face
+             of a Polyhedron in QQ^3 defined as the convex hull of 1 vertex and 1 line
+            sage: T_line = line.affine_tangent_cone()
+            sage: T_line == half_plane_in_space
+            True
+
+            sage: c = polytopes.cube()
+            sage: edge = min(c.faces(1))
+            sage: edge.vertices()
+            (A vertex at (1, -1, -1), A vertex at (1, 1, -1))
+            sage: T_edge = edge.affine_tangent_cone()
+            sage: T_edge.Vrepresentation()
+            (A line in the direction (0, 1, 0),
+            A ray in the direction (0, 0, 1),
+            A vertex at (1, 0, -1),
+            A ray in the direction (-1, 0, 0))
+        """
+        parent = self.polyhedron().parent()
+        new_ieqs = [H for H in self.ambient_Hrepresentation()
+                    if H.is_inequality()]
+        new_eqns = [H for H in self.ambient_Hrepresentation()
+                    if H.is_equation()]
+        return parent.element_class(parent, None, [new_ieqs, new_eqns])
+
+    @cached_method
+    def stacking_locus(self):
+        """
+        Return the polyhedron containing the points that sees every facet
+        containing ``self``.
+
+        OUTPUT:
+
+        A polyhedron.
+
+        EXAMPLES::
+
+            sage: cp = polytopes.cross_polytope(4)
+            sage: facet = cp.facets()[0]
+            sage: facet.stacking_locus().vertices()
+            (A vertex at (1/2, 1/2, 1/2, 1/2),
+             A vertex at (1, 0, 0, 0),
+             A vertex at (0, 0, 0, 1),
+             A vertex at (0, 0, 1, 0),
+             A vertex at (0, 1, 0, 0))
+            sage: face = cp.faces(2)[0]
+            sage: face.stacking_locus().vertices()
+            (A vertex at (0, 1, 0, 0),
+             A vertex at (0, 0, 1, 0),
+             A vertex at (1, 0, 0, 0),
+             A vertex at (1, 1, 1, 0),
+             A vertex at (1/2, 1/2, 1/2, 1/2),
+             A vertex at (1/2, 1/2, 1/2, -1/2))
+        """
+        # Taking all facets that contain the face
+        if self.dim() == self.polyhedron().dim() - 1:
+            face_star = set([self.ambient_Hrepresentation()[-1]])
+        else:
+            face_star = set(facet for facet in self.ambient_Hrepresentation() if facet.is_inequality()
+                            if all(not facet.interior_contains(x) for x in self.vertices()))
+
+        neighboring_facets = set()
+        for facet in face_star:
+            for neighbor_facet in facet.neighbors():
+                if neighbor_facet not in face_star:
+                    neighboring_facets.add(neighbor_facet)
+
+        # Create the polyhedron where we can put the new vertex
+        locus_ieqs = [facet.vector() for facet in neighboring_facets]
+        locus_ieqs += [-facet.vector() for facet in face_star]
+        locus_eqns = self.polyhedron().equations_list()
+        parent = self.polyhedron().parent().change_ring(self.polyhedron().base_ring().fraction_field())
+
+        return parent.element_class(parent, None, [locus_ieqs, locus_eqns])
 
 def combinatorial_face_to_polyhedral_face(polyhedron, combinatorial_face):
     r"""
@@ -800,12 +1053,12 @@ def combinatorial_face_to_polyhedral_face(polyhedron, combinatorial_face):
     if polyhedron.backend() in ('ppl',):
         # Equations before inequalities in Hrep.
         H_indices = tuple(range(n_equations))
-        H_indices += tuple(x+n_equations for x in combinatorial_face.ambient_H_indices())
+        H_indices += tuple(x+n_equations for x in combinatorial_face.ambient_H_indices(add_equations=False))
     elif polyhedron.backend() in ('normaliz', 'cdd', 'field', 'polymake'):
         # Equations after the inequalities in Hrep.
         n_ieqs = polyhedron.n_inequalities()
-        H_indices = tuple(range(n_ieqs, n_ieqs + n_equations))
-        H_indices += tuple(x for x in combinatorial_face.ambient_H_indices())
+        H_indices = tuple(x for x in combinatorial_face.ambient_H_indices(add_equations=False))
+        H_indices += tuple(range(n_ieqs, n_ieqs + n_equations))
     else:
         raise NotImplementedError("unknown backend")
 
