@@ -391,7 +391,6 @@ AUTHORS:
 Methods
 -------
 """
-from __future__ import print_function
 
 from sage.structure.sage_object import SageObject
 from sage.structure.unique_representation import CachedRepresentation, UniqueRepresentation
@@ -995,7 +994,7 @@ class GraphClasses(UniqueRepresentation):
         # Maximum width of a field
         MAX_LEN = 40
 
-        # Computing te max of each field with the database
+        # Computing the max of each field with the database
         for key in MAX:
             MAX[key] = len(max((str(x.get(key, "")) for x in classes_list), key=len))
 
