@@ -326,9 +326,23 @@ class AbelianGroup_gap(UniqueRepresentation, GroupMixinLibGAP, ParentLibGAP, Abe
             (2)
             sage: G(a)
             f2
+
+        TESTS:
+
+        Document that :trac:`31428` is fixed::
+
+            sage: A = AbelianGroupGap([])
+            sage: A([]) == A.one()
+            True
         """
         if isinstance(x, AbelianGroupElement_gap):
-            x = x.gap()
+            try:
+                if x in self._cover:
+                    x = self.gap().NaturalHomomorphism().Image(x.gap())
+                else:
+                    x = x.gap()
+            except AttributeError:
+                x = x.gap()
         elif x == 1 or x == ():
             x = self.gap().Identity()
         elif not isinstance(x, GapElement):
@@ -346,11 +360,14 @@ class AbelianGroup_gap(UniqueRepresentation, GroupMixinLibGAP, ParentLibGAP, Abe
                 exp = vector(ZZ, x)
             # turn the exponents into a gap element
             gens_gap = self.gens()
+            orders = self.gens_orders()
             if len(exp) != len(gens_gap):
                 raise ValueError("input does not match the number of generators")
-            x = gens_gap[0]**0
-            for i in range(len(exp)):
-                x *= gens_gap[i]**exp[i]
+            x = self.one()
+            for g, e, m in zip(gens_gap, exp, orders):
+                if m != 0:
+                    e = e % m
+                x *= g**e
             x = x.gap()
         return self.element_class(self, x, check=check)
 
@@ -548,6 +565,29 @@ class AbelianGroup_gap(UniqueRepresentation, GroupMixinLibGAP, ParentLibGAP, Abe
         generators = tuple([ambient(g) for g in generators])
         return AbelianGroupSubgroup_gap(ambient, generators)
 
+    def quotient(self, N):
+        r"""
+        Return the quotient of this group by the normal subgroup `N`.
+
+        INPUT:
+
+        - ``N`` -- a subgroup
+        - ``check`` -- bool (default: ``True``) check if `N` is normal
+
+        EXAMPLES::
+
+            sage: from sage.groups.abelian_gps.abelian_group_gap import AbelianGroupGap
+            sage: A = AbelianGroupGap([2,3,4,5])
+            sage: S = A.subgroup(A.gens()[:1])
+            sage: A.quotient(S)
+            Quotient abelian group with generator orders (1, 3, 4, 5)
+        """
+        if not isinstance(N, AbelianGroup_gap):
+            raise TypeError("not an abelian group")
+        if not N.is_subgroup_of(self):
+            raise ValueError("not a subgroup")
+        return AbelianGroupQuotient_gap(self, N)
+
     def subgroup(self, gens):
         r"""
         Return the subgroup of this group generated by ``gens``.
@@ -754,8 +794,7 @@ class AbelianGroupSubgroup_gap(AbelianGroup_gap):
             category = category.Finite()
         else:
             category = category.Infinite()
-        # FIXME: Tell the category that it is a Subobjects() category
-        # category = category.Subobjects()
+        category = category.Subobjects()
         AbelianGroup_gap.__init__(self, G, ambient=ambient, category=category)
 
     def _repr_(self):
@@ -796,3 +835,230 @@ class AbelianGroupSubgroup_gap(AbelianGroup_gap):
         gens = tuple([amb(g) for g in self.gens()])
         return amb.subgroup, (gens,)
 
+    def lift(self, x):
+        """
+        Coerce to the ambient group.
+
+        The terminology comes from the category framework and the more general notion of a subquotient.
+
+        INPUT:
+
+        - ``x`` -- an element of this subgroup
+
+        OUTPUT:
+
+        The corresponding element of the ambient group
+
+        EXAMPLES::
+
+            sage: from sage.groups.abelian_gps.abelian_group_gap import AbelianGroupGap
+            sage: G = AbelianGroupGap([4])
+            sage: g = G.gen(0)
+            sage: H = G.subgroup([g^2])
+            sage: h = H.gen(0); h
+            f2
+            sage: h.parent()
+            Subgroup of Abelian group with gap, generator orders (4,) generated by (f2,)
+            sage: H.lift(h)
+            f2
+            sage: H.lift(h).parent()
+            Abelian group with gap, generator orders (4,)
+        """
+        return self.ambient()(x)
+
+    def retract(self, x):
+        """
+        Convert an element of the ambient group into this subgroup.
+
+        The terminology comes from the category framework and the more general notion of a subquotient.
+
+        INPUT:
+
+        - ``x`` -- an element of the ambient group that actually lies in this subgroup.
+
+        OUTPUT:
+
+        The corresponding element of this subgroup
+
+        EXAMPLES::
+
+            sage: from sage.groups.abelian_gps.abelian_group_gap import AbelianGroupGap
+            sage: G = AbelianGroupGap([4])
+            sage: g = G.gen(0)
+            sage: H = G.subgroup([g^2])
+            sage: H.retract(g^2)
+            f2
+            sage: H.retract(g^2).parent()
+            Subgroup of Abelian group with gap, generator orders (4,) generated by (f2,)
+        """
+        return self(x)
+
+class AbelianGroupQuotient_gap(AbelianGroup_gap):
+    r"""
+    Quotients of abelian groups by a subgroup.
+
+    .. NOTE::
+
+        Do not call this directly. Instead use :meth:`quotient`.
+
+    EXAMPLES::
+
+        sage: from sage.groups.abelian_gps.abelian_group_gap import AbelianGroupGap
+        sage: A = AbelianGroupGap([4,3])
+        sage: N = A.subgroup([A.gen(0)^2])
+        sage: Q1 = A.quotient(N)
+        sage: Q1
+        Quotient abelian group with generator orders (2, 3)
+        sage: Q2 = Q1.quotient(Q1.subgroup(Q1.gens()[:1]))
+        sage: Q2
+        Quotient abelian group with generator orders (1, 3)
+    """
+    def __init__(self, G, N):
+        r"""
+        Constructor.
+
+        TESTS::
+
+            sage: from sage.groups.abelian_gps.abelian_group_gap import AbelianGroupGap
+            sage: G = AbelianGroupGap([2,3,4,5])
+            sage: gen = G.gens()[:2]
+            sage: S = G.subgroup(gen)
+            sage: Q = G.quotient(S)
+            sage: TestSuite(Q).run()
+        """
+        self._cover = G
+        self._relations = N
+        libgap_group = G.gap().FactorGroup(N.gap())
+        category = G.category()
+        AbelianGroup_gap.__init__(self, libgap_group, category=category, ambient=None)
+
+    def _repr_(self):
+        r"""
+        Return a string representation of this subgroup.
+
+        EXAMPLES::
+
+            sage: from sage.groups.abelian_gps.abelian_group_gap import AbelianGroupGap
+            sage: G = AbelianGroupGap([2,3,4,5])
+            sage: gen = G.gens()[:2]
+            sage: S = G.subgroup(gen)
+            sage: G.quotient(S)
+            Quotient abelian group with generator orders (1, 1, 4, 5)
+        """
+        return "Quotient abelian group with generator orders " + str(
+               self.gens_orders())
+
+    def __reduce__(self):
+        r"""
+        Implements pickling.
+
+        We have to work around the fact that gap does not provide pickling.
+
+        EXAMPLES::
+
+            sage: from sage.groups.abelian_gps.abelian_group_gap import AbelianGroupGap
+            sage: A = AbelianGroupGap([4])
+            sage: N = A.subgroup([A.gen(0)^2])
+            sage: Q = A.quotient(N)
+            sage: Q is loads(dumps(Q))
+            True
+        """
+        G = self._cover
+        N = self._relations
+        return G.quotient, (N, )
+
+    def _coerce_map_from_(self, S):
+        r"""
+        Return whether ``S`` canonically coerces to ``self``.
+
+        INPUT:
+
+        - ``S`` -- anything
+
+        OUTPUT:
+
+        Boolean.
+
+        EXAMPLES::
+
+            sage: from sage.groups.abelian_gps.abelian_group_gap import AbelianGroupGap
+            sage: G = AbelianGroupGap([2,3,4,5])
+            sage: gen = G.gens()[:2]
+            sage: S = G.subgroup(gen)
+            sage: Q = G.quotient(S)
+            sage: Q._coerce_map_from_(G)
+            True
+            sage: G._coerce_map_from_(Q)
+            False
+        """
+        if isinstance(S, AbelianGroup_gap):
+            return self._cover._coerce_map_from_(S)
+
+
+    def cover(self):
+        r"""
+        Return the covering group of this quotient group.
+
+        EXAMPLES::
+
+            sage: from sage.groups.abelian_gps.abelian_group_gap import AbelianGroupGap
+            sage: G = AbelianGroupGap([2,3,4,5])
+            sage: gen = G.gens()[:2]
+            sage: S = G.subgroup(gen)
+            sage: Q = G.quotient(S)
+            sage: Q.cover() is G
+            True
+        """
+        return self._cover
+
+    def relations(self):
+        r"""
+        Return the relations of this quotient group.
+
+        EXAMPLES::
+
+            sage: from sage.groups.abelian_gps.abelian_group_gap import AbelianGroupGap
+            sage: G = AbelianGroupGap([2,3,4,5])
+            sage: gen = G.gens()[:2]
+            sage: S = G.subgroup(gen)
+            sage: Q = G.quotient(S)
+            sage: Q.relations() is S
+            True
+        """
+        return self._relations
+
+    @cached_method
+    def natural_homomorphism(self):
+        r"""
+        Return the defining homomorphism into ``self``.
+
+        EXAMPLES::
+
+            sage: from sage.groups.abelian_gps.abelian_group_gap import AbelianGroupGap
+            sage: A = AbelianGroupGap([4])
+            sage: N = A.subgroup([A.gen(0)^2])
+            sage: Q = A.quotient(N)
+            sage: Q.natural_homomorphism()
+            Group morphism:
+            From: Abelian group with gap, generator orders (4,)
+            To:   Quotient abelian group with generator orders (2,)
+        """
+        phi = self.gap().NaturalHomomorphism()
+        Hom = self._cover.Hom(self)
+        return Hom(phi)
+
+    def lift(self, x):
+        r"""
+        Lift an element to the cover.
+
+        EXAMPLES::
+
+            sage: from sage.groups.abelian_gps.abelian_group_gap import AbelianGroupGap
+            sage: A = AbelianGroupGap([4])
+            sage: N = A.subgroup([A.gen(0)^2])
+            sage: Q = A.quotient(N)
+            sage: Q.lift(Q.0)
+            f1
+        """
+        x = self(x)
+        return self.natural_homomorphism().lift(x)
