@@ -232,7 +232,6 @@ loaded.
 #
 #                  https://www.gnu.org/licenses/
 #############################################################################
-from __future__ import print_function, absolute_import
 
 import os
 
@@ -273,30 +272,30 @@ class Maple(ExtraTabCompletion, Expect):
         """
         __maple_iface_opts = [
             'screenwidth=infinity',
-            'errorcursor=false',]
+            'errorcursor=false']
         __maple_command = 'maple -t -c "interface({})"'.format(
             ','.join(__maple_iface_opts))
-        #errorcursor=false avoids maple command line interface to dump
-        #into the editor when an error occurs. Thus pexpect interface
-        #is not messed up if a maple error occurs.
-        #screenwidth=infinity prevents maple command interface from cutting 
-        #your input lines. By doing this, file interface also works in the
-        #event that  sage_user_home + sage_tmp_file_stuff exceeds the 
-        #length of 79 characters.
+        # errorcursor=false avoids maple command line interface to dump
+        # into the editor when an error occurs. Thus pexpect interface
+        # is not messed up if a maple error occurs.
+        # screenwidth=infinity prevents maple command interface from cutting
+        # your input lines. By doing this, file interface also works in the
+        # event that  sage_user_home + sage_tmp_file_stuff exceeds the
+        # length of 79 characters.
         Expect.__init__(self,
-                        name = 'maple',
-                        prompt = '#-->',
-                        command = __maple_command,
-                        server = server,
-                        server_tmpdir = server_tmpdir,
-                        ulimit = ulimit,
-                        script_subdirectory = script_subdirectory,
-                        restart_on_ctrlc = False,
-                        verbose_start = False,
-                        logfile = logfile,
+                        name='maple',
+                        prompt='#-->',
+                        command=__maple_command,
+                        server=server,
+                        server_tmpdir=server_tmpdir,
+                        ulimit=ulimit,
+                        script_subdirectory=script_subdirectory,
+                        restart_on_ctrlc=False,
+                        verbose_start=False,
+                        logfile=logfile,
                         eval_using_file_cutoff=2048)  # 2048 is
-        #a small enough value to avoid conflicts with the 4096 limit  
-        #hardcoded in Expect. 
+        # a small enough value to avoid conflicts with the 4096 limit
+        # hardcoded in Expect.
 
     def _function_class(self):
         """
@@ -348,7 +347,7 @@ class Maple(ExtraTabCompletion, Expect):
 
     def _read_in_file_command(self, filename):
         r"""
-        Returns the string used to read filename into Maple.
+        Return the string used to read filename into Maple.
 
         EXAMPLES::
 
@@ -425,7 +424,7 @@ connection to a server running Maple; for hints, type
 
     def expect(self):
         """
-        Returns the pexpect object for this Maple session.
+        Return the pexpect object for this Maple session.
 
         EXAMPLES::
 
@@ -455,24 +454,24 @@ connection to a server running Maple; for hints, type
         """
         maple_console()
 
-##     def killall(self):
-##         """
-##         Kill all running instances of the maple interpreter
-##         on this system.
+#     def killall(self):
+#         """
+#         Kill all running instances of the maple interpreter
+#         on this system.
 
-##         TODO: When Sage exits it doesn't correctly by default kill
-##         all running Maple interpreters, for some strange reason.
-##         Calling this function uses the kill and pidof operating system
-##         programs to find all instances of cmaple and kill them.
-##         """
-##         import os
-##         self._expect = None
-##         while True:
-##             pid = os.popen("pidof cmaple").read()[:-1]
-##             if len(pid) > 0:
-##                 os.system('kill -9 %s'%pid)
-##             else:
-##                 break
+#         TODO: When Sage exits it doesn't correctly by default kill
+#         all running Maple interpreters, for some strange reason.
+#         Calling this function uses the kill and pidof operating system
+#         programs to find all instances of cmaple and kill them.
+#         """
+#         import os
+#         self._expect = None
+#         while True:
+#             pid = os.popen("pidof cmaple").read()[:-1]
+#             if len(pid) > 0:
+#                 os.system('kill -9 %s'%pid)
+#             else:
+#                 break
 
     def completions(self, s):
         """
@@ -485,13 +484,13 @@ connection to a server running Maple; for hints, type
             sage: 'divide' in c                # optional - maple
             True
         """
-        bs = chr(8)*len(s)
+        bs = chr(8) * len(s)
         if self._expect is None:
             self._start()
         E = self._expect
         E.sendline('%s%s%s' % (s, chr(20), bs))
         t = E.timeout
-        E.timeout=0.3  # since some things have no completion
+        E.timeout = 0.3  # since some things have no completion
         try:
             E.expect('----')
         except pexpect.TIMEOUT:
@@ -516,8 +515,8 @@ connection to a server running Maple; for hints, type
             True
         """
         try:
-            v = sum([self.completions(chr(65+n)) for n in range(26)], []) + \
-                sum([self.completions(chr(97+n)) for n in range(26)], [])
+            v = sum([self.completions(chr(65 + n)) for n in range(26)], []) + \
+                sum([self.completions(chr(97 + n)) for n in range(26)], [])
         except RuntimeError:
             print("\n" * 3)
             print("*" * 70)
@@ -529,7 +528,7 @@ connection to a server running Maple; for hints, type
 
     def _tab_completion(self, verbose=True, use_disk_cache=True):
         """
-        Returns a list of all the commands defined in Maple and optionally
+        Return a list of all the commands defined in Maple and optionally
         (per default) store them to disk.
 
         EXAMPLES::
@@ -571,7 +570,7 @@ connection to a server running Maple; for hints, type
         line += ';'
         with gc_disabled():
             z = Expect._eval_line(self, line, allow_use_file=allow_use_file,
-                    wait_for_prompt=wait_for_prompt).replace('\\\n','').strip()
+                    wait_for_prompt=wait_for_prompt).replace('\\\n', '').strip()
             if z.lower().find("error") != -1:
                 raise RuntimeError("An error occurred running a Maple command:\nINPUT:\n%s\nOUTPUT:\n%s" % (line, z))
         return z
@@ -588,7 +587,7 @@ connection to a server running Maple; for hints, type
 
     def cputime(self, t=None):
         r"""
-        Returns the amount of CPU time that the Maple session has used. If
+        Return the amount of CPU time that the Maple session has used. If
         ``t`` is not None, then it returns the difference
         between the current CPU time and ``t``.
 
@@ -606,7 +605,7 @@ connection to a server running Maple; for hints, type
         if t is None:
             return float(self('time()'))
         else:
-            return float(self('time() - %s'%float(t)))
+            return float(self('time() - %s' % float(t)))
 
     def set(self, var, value):
         """
@@ -633,12 +632,11 @@ connection to a server running Maple; for hints, type
             sage: maple.get('xx')      # optional - maple
             '2'
         """
-        s = self.eval('printf("%%q",%s)'%var)
-        return s
+        return self.eval('printf("%%q",%s)' % var)
 
     def _object_class(self):
         """
-        Returns the class of MapleElements.
+        Return the class of MapleElements.
 
         EXAMPLES::
 
@@ -655,7 +653,7 @@ connection to a server running Maple; for hints, type
 
     def _function_element_class(self):
         """
-        Returns the MapleFunctionElement class.
+        Return the MapleFunctionElement class.
 
         EXAMPLES::
 
@@ -672,7 +670,7 @@ connection to a server running Maple; for hints, type
 
     def _equality_symbol(self):
         """
-        Returns the symbol used for equality testing in Maple.
+        Return the symbol used for equality testing in Maple.
 
         EXAMPLES::
 
@@ -686,7 +684,7 @@ connection to a server running Maple; for hints, type
 
     def _true_symbol(self):
         """
-        Returns the symbol used for truth in Maple.
+        Return the symbol used for truth in Maple.
 
         EXAMPLES::
 
@@ -702,7 +700,7 @@ connection to a server running Maple; for hints, type
 
     def _assign_symbol(self):
         """
-        Returns the symbol used for assignment in Maple.
+        Return the symbol used for assignment in Maple.
 
         EXAMPLES::
 
@@ -725,7 +723,7 @@ connection to a server running Maple; for hints, type
             ...
             Exception: no source code could be found
         """
-        cmd = 'echo "interface(verboseproc=2): print(%s);" | maple -q'%s
+        cmd = 'echo "interface(verboseproc=2): print(%s);" | maple -q' % s
         src = os.popen(cmd).read()
         if src.strip() == s:
             raise RuntimeError("no source code could be found")
@@ -815,7 +813,7 @@ connection to a server running Maple; for hints, type
             sage: maple('fibonacci(10)')              # optional - maple
             55
         """
-        self.eval('with(%s)'%package)
+        self.eval('with(%s)' % package)
 
     load = with_package
 
@@ -842,7 +840,7 @@ connection to a server running Maple; for hints, type
 class MapleFunction(ExpectFunction):
     def _instancedoc(self):
         """
-        Returns the Maple help for this function. This gets called when
+        Return the Maple help for this function. This gets called when
         doing "?" on self.
 
         EXAMPLES::
@@ -856,7 +854,7 @@ class MapleFunction(ExpectFunction):
 
     def _sage_src_(self):
         """
-        Returns the source code of ``self``.
+        Return the source code of ``self``.
 
         This is the function that eventually gets called when doing
         maple.gcd?? for example.
@@ -865,7 +863,7 @@ class MapleFunction(ExpectFunction):
 
             sage: print(maple.curry._sage_src_().strip()) # optional - maple
             p -> subs('_X' = args[2 .. nargs], () -> p(_X, args))
-            sage: maple.ZZZ._sage_src_()                 #not tested 
+            sage: maple.ZZZ._sage_src_()                 #not tested
             Traceback (most recent call last):
             ...
             Exception: no source code could be found
@@ -878,7 +876,7 @@ class MapleFunction(ExpectFunction):
 class MapleFunctionElement(FunctionElement):
     def _instancedoc_(self):
         """
-        Returns the Maple help for this function.
+        Return the Maple help for this function.
 
         This gets called when doing "?" on ``self``.
 
@@ -893,7 +891,7 @@ class MapleFunctionElement(FunctionElement):
 
     def _sage_src_(self):
         """
-        Returns the source code of self.
+        Return the source code of self.
 
         EXAMPLES::
 
@@ -901,20 +899,20 @@ class MapleFunctionElement(FunctionElement):
             sage: print(g.curry._sage_src_().strip()) # optional - maple
             p -> subs('_X' = args[2 .. nargs], () -> p(_X, args))
             sage: m = maple('2')                     # optional - maple
-            sage: m.ZZZ._sage_src_()                 #not tested 
+            sage: m.ZZZ._sage_src_()                 #not tested
             Traceback (most recent call last):
             ...
             Exception: no source code could be found
         """
         return self._obj.parent()._source(self._name)
 
-    
+
 @instancedoc
 class MapleElement(ExtraTabCompletion, ExpectElement):
-    
+
     def __float__(self):
         """
-        Returns a floating point version of self.
+        Return a floating point version of self.
 
         EXAMPLES::
 
@@ -927,7 +925,7 @@ class MapleElement(ExtraTabCompletion, ExpectElement):
 
     def __hash__(self):
         """
-        Returns a 64-bit integer representing the hash of self. Since
+        Return a 64-bit integer representing the hash of self. Since
         Python uses 32-bit hashes, it will automatically convert the result
         of this to a 32-bit hash.
 
@@ -939,15 +937,15 @@ class MapleElement(ExtraTabCompletion, ExpectElement):
             sage: m = maple('x^2+y^2')                      # optional - maple
             sage: m.__hash__()                              # optional - maple
             188724254834261060184983038723355865733L
-            sage: hash(m)                                   # optional - maple
+            sage: hash(m)               # random            # optional - maple
             5035731711831192733
             sage: m = maple('x^2+y^3')                      # optional - maple
-            sage: m.__hash__()                              # optional - maple
+            sage: m.__hash__()          # random            # optional - maple
             264835029579301191531663246434344770556L
-            sage: hash(m)                                   # optional - maple
+            sage: hash(m)               # random            # optional - maple
             -2187277978252104690
         """
-        return int(maple.eval('StringTools:-Hash(convert(%s, string))'%self.name())[1:-1],16)
+        return int(maple.eval('StringTools:-Hash(convert(%s, string))' % self.name())[1:-1], 16)
 
     def _richcmp_(self, other, op):
         """
@@ -983,12 +981,6 @@ class MapleElement(ExtraTabCompletion, ExpectElement):
             sage: Mm = maple(M)                            # optional - maple
             sage: Mm == Mm                                 # optional - maple
             True
-            sage: Mm < 5                                   # optional - maple
-            True
-            sage: (Mm < 5) == (M < 5)                      # optional - maple
-            True
-            sage: 5 < Mm                                   # optional - maple
-            False
 
         TESTS::
 
@@ -1082,13 +1074,31 @@ class MapleElement(ExtraTabCompletion, ExpectElement):
             \pi-{{\rm e}^{3}}
             sage: print(maple(pi - e^3)._latex_())              # optional - maple
             \pi-{{\rm e}^{3}}
- 
+
         .. note::
 
            Some expressions might require the Maple style file
            ``maple2e.sty`` in order to latex correctly.
         """
-        return self.parent().eval('latex(%s)'%self.name())
+        return self.parent().eval('latex(%s)' % self.name())
+
+    def op(self, i):
+        """
+        Return the i-th operand of this expression.
+
+        INPUT:
+
+        - i -- an integer
+
+        EXAMPLES::
+
+            sage: V = maple(vector(QQ,[4,5,6]))      # optional - maple
+            sage: V.op(1)                            # optional - maple
+            3
+            sage: V.op(2)                            # optional - maple
+            {1 = 4, 2 = 5, 3 = 6}
+        """
+        return self.parent().op(i, self)
 
     def _sage_(self):
         r"""
@@ -1097,16 +1107,18 @@ class MapleElement(ExtraTabCompletion, ExpectElement):
         This currently does not implement a parser for the Maple output language,
         therefore only very simple expressions will convert successfully.
 
+        REFERENCE:
+
+        https://www.asc.tuwien.ac.at/compmath/download/Monagan_Maple_Programming.pdf
+
         EXAMPLES::
 
-            sage: m = maple('x^2 + 5*y')                            # optional - maple
-            sage: m.sage()                                          # optional - maple
+            sage: m = maple('x^2 + 5*y')        # optional - maple
+            sage: m.sage()                      # optional - maple
             x^2 + 5*y
-            sage: m._sage_()                                        # optional - maple
+            sage: m._sage_()                    # optional - maple
             x^2 + 5*y
 
-        ::
-
             sage: m = maple('sin(sqrt(1-x^2)) * (1 - cos(1/x))^2')  # optional - maple
             sage: m.sage()                                          # optional - maple
             (cos(1/x) - 1)^2*sin(sqrt(-x^2 + 1))
@@ -1124,41 +1136,104 @@ class MapleElement(ExtraTabCompletion, ExpectElement):
             sage: mm = maple(m)                     # optional - maple
             sage: mm.sage() == m                    # optional - maple
             True
+
+        Integers and rationals are converted as such::
+
+            sage: maple(33).sage().parent()         # optional - maple
+            Integer Ring
+            sage: maple(191/5).sage().parent()      # optional - maple
+            Rational Field
+
+        Sets, lists, sequences::
+
+            sage: maple("[4,5,6]").sage()           # optional - maple
+            [4, 5, 6]
+            sage: maple({14,33,6}).sage()           # optional - maple
+            {6, 14, 33}
+            sage: maple("seq(i**2,i=1..5)").sage()  # optional - maple
+            (1, 4, 9, 16, 25)
+
+        Strings::
+
+            sage: maple('"banane"').sage()          # optional - maple
+            '"banane"'
+
+        Floats::
+
+            sage: Z3 = maple('evalf(Zeta(3))')   # optional - maple
+            sage: Z3.sage().parent()             # optional - maple
+            Real Field with 53 bits of precision
+
+            sage: sq5 = maple('evalf(sqrt(5),100)')   # optional - maple
+            sage: sq5 = sq5.sage(); sq5               # optional - maple
+            2.23606797749978969640...
+            sage: sq5.parent()                        # optional - maple
+            Real Field with 332 bits of precision
+
+        Functions are not yet converted back correctly::
+
+            sage: maple(hypergeometric([3,4],[5],x))  # optional - maple
+            hypergeom([3, 4],[5],x)
+            sage: _.sage()                # known bug # optional - maple
+            hypergeometric((3, 4), (5,), x)
         """
         from sage.matrix.constructor import matrix
         from sage.modules.free_module_element import vector
         from sage.rings.integer_ring import ZZ
-
+        # The next few lines are a very crude excuse for a maple "parser"
+        maple_type = repr(self.whattype())
         result = repr(self)
-        # The next few lines are a very crude excuse for a maple "parser".
         result = result.replace("Pi", "pi")
-
-        if result[:6] == "Matrix":
-            content = result[7:-1]
-            m, n = content.split(',')[:2]
-            m = ZZ(m.strip())
-            n = ZZ(n.strip())
-            coeffs = [self[i + 1, j + 1].sage()
+        if maple_type == 'symbol':       # pi
+            pass   # left to symbolic ring
+        elif maple_type == 'string':     # "banane"
+            return result
+        elif maple_type == 'exprseq':   # 2, 2
+            n = self.parent()(f"[{self._name}]").nops()._sage_()
+            return tuple(self[i] for i in range(1, n + 1))
+        elif maple_type == 'set':        # {1, 2}
+            n = self.nops()._sage_()
+            return set(self.op(i)._sage_() for i in range(1, n + 1))
+        elif maple_type == 'list':        # [1, 2]
+            n = self.nops()._sage_()
+            return [self.op(i)._sage_() for i in range(1, n + 1)]
+        elif maple_type == "Matrix":     # Matrix(2, 2, [[1,2],[3,4]])
+            mn = self.op(1)
+            m = mn[1]._sage_()
+            n = mn[2]._sage_()
+            coeffs = [self[i + 1, j + 1]._sage_()
                       for i in range(m) for j in range(n)]
             return matrix(m, n, coeffs)
-        elif result[:6] == "Vector":
-            start = result.index('(')
-            content = result[start + 1:-1]
-            m = ZZ(content.split(',')[0].strip())
-            return vector([self[i + 1].sage() for i in range(m)])
-
+        elif maple_type[:6] == "Vector":  # Vector[row](3, [4,5,6])
+            n = self.op(1)._sage_()
+            return vector([self[i + 1]._sage_() for i in range(n)])
+        elif maple_type == 'integer':
+            return ZZ(result)
+        elif maple_type == 'fraction':
+            return self.op(1)._sage_() / self.op(2)._sage_()
+        elif maple_type == "function":
+            pass  # TODO : here one should translate back function names
+        elif maple_type == "float":
+            from sage.rings.real_mpfr import RealField
+            mantissa = len(repr(self.op(1)))
+            prec = max(53, (mantissa * 13301) // 4004)
+            R = RealField(prec)
+            return R(result)
+        elif maple_type == '`=`':        # (1, 1) = 2
+            return (self.op(1)._sage_() == self.op(2)._sage())
         try:
             from sage.symbolic.all import SR
             return SR(result)
         except Exception:
             raise NotImplementedError("Unable to parse Maple output: %s" % result)
 
-# An instance
-maple = Maple()
+
+maple = Maple()  # an instance
+
 
 def reduce_load_Maple():
     """
-    Returns the maple object created in sage.interfaces.maple.
+    Return the maple object created in sage.interfaces.maple.
 
     EXAMPLES::
 
@@ -1205,7 +1280,6 @@ def __doctest_cleanup():
     sage.interfaces.quit.expect_quitall()
 
 
-
 """
 The following only works in Maple >= 9, I guess, but could
 be useful.
