@@ -146,8 +146,6 @@ language works). Use square brackets or the set function::
 #
 #                  http://www.gnu.org/licenses/
 ##############################################################################
-from __future__ import print_function
-from __future__ import absolute_import
 
 import os
 
