@@ -44,7 +44,7 @@ void testL(L_function<Complex> *L)
 {
     int i;
     cout << "number of coefficients " << L->number_of_dirichlet_coefficients << endl;
-    cout << "dirichlet coeffs"<< endl;
+    cout << "Dirichlet coeffs"<< endl;
     for (i=0;i< min(30, L->number_of_dirichlet_coefficients +1); i++)
         cout << L->dirichlet_coefficient[i]<<endl;
     cout << "Q " << L->Q << endl;
