@@ -25,7 +25,6 @@ AUTHORS:
 # (at your option) any later version.
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
-from __future__ import division
 
 from sage.calculus.functions import jacobian
 from sage.functions.hyperbolic import cosh, sinh
@@ -34,7 +33,7 @@ from sage.matrix.constructor import matrix
 from sage.misc.misc_c import prod
 from sage.modules.free_module_element import vector
 from sage.rings.all import CC
-from sage.rings.complex_field import ComplexField
+from sage.rings.complex_mpfr import ComplexField
 from sage.rings.complex_interval_field import ComplexIntervalField
 from sage.rings.integer_ring import ZZ
 from sage.rings.laurent_series_ring import LaurentSeriesRing
@@ -136,20 +135,20 @@ def covariant_z0(F, z0_cov=False, prec=53, emb=None, error_limit=0.000001):
     if d < 3:
         raise ValueError('must be at least degree 3')
 
-    f = F.subs({R.gen(1):1}).univariate_polynomial()
+    f = F.subs({R.gen(1): 1}).univariate_polynomial()
     if f.degree() < d:
         # we have a root at infinity
         if f.constant_coefficient() != 0:
             # invert so we find all roots!
-            mat = matrix(ZZ,2,2,[0,-1,1,0])
+            mat = matrix(ZZ, 2, 2, [0, -1, 1, 0])
         else:
             t = 0
             while f(t) == 0:
                 t += 1
-            mat = matrix(ZZ,2,2,[t,-1,1,0])
+            mat = matrix(ZZ, 2, 2, [t, -1, 1, 0])
     else:
-        mat = matrix(ZZ,2,2,[1,0,0,1])
-    f = F(list(mat * vector(R.gens()))).subs({R.gen(1):1}).univariate_polynomial()
+        mat = matrix(ZZ, 2, 2, [1, 0, 0, 1])
+    f = F(list(mat * vector(R.gens()))).subs({R.gen(1): 1}).univariate_polynomial()
     # now we have a single variable polynomial with all the roots of F
     K = ComplexField(prec=prec)
     if f.base_ring() != K:
@@ -163,7 +162,7 @@ def covariant_z0(F, z0_cov=False, prec=53, emb=None, error_limit=0.000001):
             raise ValueError('cannot have multiple roots for z0 invariant')
         else:
             # just need a starting point for Newton's method
-            f = f.lc()*prod([p for p,ex in f.factor()])# removes multiple roots
+            f = f.lc() * prod(p for p, ex in f.factor())  # removes multiple roots
             if f.degree() < 3:
                 raise ValueError('must have at least 3 distinct roots')
             roots = f.roots()
@@ -172,71 +171,73 @@ def covariant_z0(F, z0_cov=False, prec=53, emb=None, error_limit=0.000001):
     # finding quadratic Q_0, gives us our covariant, z_0
     dF = f.derivative()
     n = ZZ(f.degree())
-    PR = PolynomialRing(K,'x,y')
-    x,y = PR.gens()
+    PR = PolynomialRing(K, 'x,y')
+    x, y = PR.gens()
     # finds Stoll and Cremona's Q_0
-    q  = sum([(1/(dF(r).abs()**(2/(n-2)))) * ((x-(r*y)) * (x-(r.conjugate()*y)))\
-              for r in roots])
+    q = sum([(1/(dF(r).abs()**(2/(n-2)))) * ((x-(r*y)) * (x-(r.conjugate()*y)))
+             for r in roots])
     # this is Q_0 , always positive def as long as F has distinct roots
     A = q.monomial_coefficient(x**2)
-    B = q.monomial_coefficient(x*y)
+    B = q.monomial_coefficient(x * y)
     C = q.monomial_coefficient(y**2)
     # need positive root
     try:
-        z = ((-B + ((B**2)-(4*A*C)).sqrt())/(2*A))
+        z = ((-B + ((B**2)-(4*A*C)).sqrt()) / (2 * A))
     except ValueError:
         raise ValueError("not enough precision")
     if z.imag() < 0:
-        z = (-B - ((B**2)-(4*A*C)).sqrt())/(2*A)
+        z = (-B - ((B**2)-(4*A*C)).sqrt()) / (2 * A)
 
     if z0_cov:
-        FM = f # for Julia's invariant
+        FM = f  # for Julia's invariant
     else:
         # solve the minimization problem for 'true' covariant
-        CF = ComplexIntervalField(prec=prec) # keeps trac of our precision error
+        CF = ComplexIntervalField(prec=prec)  # keeps trac of our precision error
         z = CF(z)
-        FM = F(list(mat * vector(R.gens()))).subs({R.gen(1):1}).univariate_polynomial()
+        FM = F(list(mat * vector(R.gens()))).subs({R.gen(1): 1}).univariate_polynomial()
         from sage.rings.polynomial.complex_roots import complex_roots
         L1 = complex_roots(FM, min_prec=prec)
         L = []
-        err = z.diameter()
         # making sure multiplicity isn't too large using convergence conditions in paper
-        for p,e in L1:
-            if e >= d/2:
-                raise ValueError('cannot have a root with multiplicity >= %s/2'%d)
+        for p, e in L1:
+            if e >= d / 2:
+                raise ValueError('cannot have a root with multiplicity >= %s/2' % d)
             for _ in range(e):
                 L.append(p)
         RCF = PolynomialRing(CF, 'u,t')
-        a = RCF(0)
-        c = RCF(0)
-        u,t = RCF.gens()
+        a = RCF.zero()
+        c = RCF.zero()
+        u, t = RCF.gens()
         for l in L:
-            a += u**2/((t-l) * (t-l.conjugate()) + u**2)
-            c += (t-l.real())/((t-l) * (t-l.conjugate()) + u**2)
+            denom = ((t - l) * (t - l.conjugate()) + u**2)
+            a += u**2 / denom
+            c += (t - l.real()) / denom
         # Newton's Method, to find solutions. Error bound is less than diameter of our z
         err = z.diameter()
         zz = z.diameter()
-        g1 = a.numerator() - d/2*a.denominator()
+        g1 = a.numerator() - d / 2 * a.denominator()
         g2 = c.numerator()
         G = vector([g1, g2])
         J = jacobian(G, [u, t])
-        v0 = vector([z.imag(), z.real()]) # z0 as starting point
+        v0 = vector([z.imag(), z.real()])  # z0 as starting point
         # finds our correct z
         while err <= zz:
-            NJ = J.subs({u:v0[0], t:v0[1]})
+            NJ = J.subs({u: v0[0], t: v0[1]})
             NJinv = NJ.inverse()
             # inverse for CIF matrix seems to return fractions not CIF elements, fix them
             if NJinv.base_ring() != CF:
-                NJinv = matrix(CF, 2, 2, [CF(zw.numerator()/zw.denominator()) for zw in NJinv.list()])
+                NJinv = matrix(CF, 2, 2, [CF(zw.numerator() / zw.denominator())
+                                          for zw in NJinv.list()])
             w = z
-            v0 = v0 - NJinv*G.subs({u:v0[0], t:v0[1]})
+            v0 = v0 - NJinv*G.subs({u: v0[0], t: v0[1]})
             z = v0[1].constant_coefficient() + v0[0].constant_coefficient()*CF.gen(0)
             err = z.diameter() # precision
-            zz = (w - z).abs() # difference in w and z
+            zz = (w - z).abs().lower() # difference in w and z
         else:
+            # despite there is no break, this happens
             if err > error_limit or err.is_NaN():
-                raise ValueError("accuracy of Newton's root not within tolerance(%s > %s), increase precision"%(err, error_limit))
-        if z.imag() <= z.diameter():
+                raise ValueError("accuracy of Newton's root not within tolerance(%s > %s), increase precision" % (err, error_limit))
+        if z.imag().upper() <= z.diameter():
             raise ArithmeticError("Newton's method converged to z not in the upper half plane")
         z = z.center()
 
@@ -246,19 +247,19 @@ def covariant_z0(F, z0_cov=False, prec=53, emb=None, error_limit=0.000001):
     tF = z.real()
     uF = z.imag()
     th = FM.lc().abs()**2
-    for r,ex in FM.roots():
+    for r, ex in FM.roots():
         for _ in range(ex):
             th = th * ((((r-tF).abs())**2 + uF**2)/uF)
 
     # undo shift and invert (if needed)
     # since F \cdot m ~ m^(-1)\cdot z
     # we apply m to z to undo m acting on F
-    l = mat*vector([z,1])
-    return l[0]/l[1], th
+    l = mat * vector([z, 1])
+    return l[0] / l[1], th
 
 
-#// compute inverse of eps_F
-#from Michael Stoll
+# // compute inverse of eps_F
+# from Michael Stoll
 def epsinv(F, target, prec=53, target_tol=0.001, z=None, emb=None):
     """
     Compute a bound on the hyperbolic distance.
@@ -291,40 +292,37 @@ def epsinv(F, target, prec=53, target_tol=0.001, z=None, emb=None):
         sage: epsinv(-2*x^3 + 2*x^2*y + 3*x*y^2 + 127*y^3, 31.5022020249597) # tol 1e-12
         4.02520895942207
     """
-    def coshdelta(z):
-        #The cosh of the hyperbolic distance from z = t+uj to j
-        return (z.norm() + 1)/(2*z.imag())
-
     def RQ(delta):
         # this is the quotient R(F_0,z)/R(F_0,z(F)) for a generic z
         # at distance delta from j. See Lemma 4.2 in [HS2018].
         cd = cosh(delta).n(prec=prec)
         sd = sinh(delta).n(prec=prec)
-        return prod([cd + (cost*phi[0] + sint*phi[1])*sd for phi in phis])
+        return prod([cd + (cost * phi[0] + sint * phi[1]) * sd for phi in phis])
 
     def epsF(delta):
-        pol = RQ(delta) #get R quotient in terms of z
+        pol = RQ(delta)  # get R quotient in terms of z
         S = PolynomialRing(C, 'v')
-        g = S([(i-d)*pol[i-d] for  i in range(2*d+1)]) # take derivative
-        drts = [e for e in g.roots(ring=C, multiplicities=False) if (e.norm()-1).abs() < 0.1]
+        g = S([(i - d) * pol[i - d] for i in range(2 * d + 1)])  # take derivative
+        drts = [e for e in g.roots(ring=C, multiplicities=False)
+                if (e.norm() - 1).abs() < 0.1]
         # find min
-        return min([pol(r/r.abs()).real() for r in drts])
+        return min([pol(r / r.abs()).real() for r in drts])
 
     C = ComplexField(prec=prec)
     R = F.parent()
     d = F.degree()
     if z is None:
         z, th = covariant_z0(F, prec=prec, emb=emb)
-    else: #need to do our own input checking
+    else:  # need to do our own input checking
         if R.ngens() != 2 or any(sum(t) != d for t in F.exponents()):
             raise TypeError('must be a binary form')
         if d < 3:
             raise ValueError('must be at least degree 3')
 
-    f = F.subs({R.gen(1):1}).univariate_polynomial()
-    #now we have a single variable polynomial
-    if (max([ex for p,ex in f.roots(ring=C)]) >= QQ(d)/2)\
-      or (f.degree() < QQ(d)/2):
+    f = F.subs({R.gen(1): 1}).univariate_polynomial()
+    # now we have a single variable polynomial
+    if (max(ex for p, ex in f.roots(ring=C)) >= QQ(d)/2 or
+            f.degree() < QQ(d)/2):
         raise ValueError('cannot have root with multiplicity >= deg(F)/2')
 
     R = RealField(prec=prec)
@@ -334,46 +332,54 @@ def epsinv(F, target, prec=53, target_tol=0.001, z=None, emb=None):
     # first find F_0 and its roots
     # this change of variables on f moves z(f) to j, i.e. produces F_0
     rts = f(z.imag()*t + z.real()).roots(ring=C)
-    phis = [] # stereographic projection of roots
-    for r,e in rts:
+    phis = []  # stereographic projection of roots
+    for r, e in rts:
         phis.extend([[2*r.real()/(r.norm()+1), (r.norm()-1)/(r.norm()+1)]])
-    if d != f.degree(): # include roots at infinity
-        phis.extend([(d-f.degree())*[0,1]])
+    if d != f.degree():  # include roots at infinity
+        phis.extend([(d - f.degree()) * [0, 1]])
 
     # for writing RQ in terms of generic z to minimize
-    LC = LaurentSeriesRing(C, 'u', default_prec=2*d+2)
+    LC = LaurentSeriesRing(C, 'u', default_prec=2 * d + 2)
     u = LC.gen(0)
-    cost = (u + u**(-1))/2
-    sint = (u - u**(-1))/(2*C.gen(0))
+    cost = (u + u**(-1)) / 2
+    sint = (u - u**(-1)) / (2 * C.gen(0))
 
     # first find an interval containing the desired value
     # then use regula falsi on log eps_F
     # d -> delta value in interval [0,1]
     # v in value in interval [1,epsF(1)]
-    dl = R(0.0); vl = R(1.0)
-    du = R(1.0); vu = epsF(du)
+    dl = R(0.0)
+    vl = R(1.0)
+    du = R(1.0)
+    vu = epsF(du)
     while vu < target:
         # compute the next value of epsF for delta = 2*delta
-        dl = du; vl = vu
-        du *= 2; vu = epsF(du)
+        dl = du
+        vl = vu
+        du *= 2
+        vu = epsF(du)
     # now dl < delta <= du
     logt = target.log()
-    l2 = (vu.log() -logt).n(prec=prec)
-    l1 = (vl.log()-logt).n(prec=prec)
+    l2 = (vu.log() - logt).n(prec=prec)
+    l1 = (vl.log() - logt).n(prec=prec)
     dn = (dl*l2 - du*l1)/(l2 - l1)
     vn = epsF(dn)
-    dl = du; vl = vu
-    du = dn; vu = vn
-    while (du-dl).abs() >= target_tol or max(vl, vu) < target:
-        l2 = (vu.log() -logt).n(prec=prec)
-        l1 = (vl.log()-logt).n(prec=prec)
-        dn = (dl*l2 - du*l1)/(l2 - l1)
+    dl = du
+    vl = vu
+    du = dn
+    vu = vn
+    while (du - dl).abs() >= target_tol or max(vl, vu) < target:
+        l2 = (vu.log() - logt).n(prec=prec)
+        l1 = (vl.log() - logt).n(prec=prec)
+        dn = (dl * l2 - du * l1) / (l2 - l1)
         vn = epsF(dn)
-        dl = du; vl = vu
-        du = dn; vu = vn
+        dl = du
+        vl = vu
+        du = dn
+        vu = vn
     return max(dl, du)
 
-###################
+
 def get_bound_poly(F, prec=53, norm_type='norm', emb=None):
     """
     The hyperbolic distance from `j` which must contain the smallest poly.
@@ -404,10 +410,6 @@ def get_bound_poly(F, prec=53, norm_type='norm', emb=None):
         sage: get_bound_poly(F, norm_type='height') # tol 1e-11
         111.890642019092
     """
-    def coshdelta(z):
-        #The cosh of the hyperbolic distance from z = t+uj to j
-        return (z.norm() + 1)/(2*z.imag())
-
     if F.base_ring() != ComplexField(prec=prec):
         if emb is None:
             compF = F.change_ring(ComplexField(prec=prec))
@@ -416,16 +418,16 @@ def get_bound_poly(F, prec=53, norm_type='norm', emb=None):
     else:
         compF = F
     n = F.degree()
-    assert(n>2), "degree 2 polynomial"
+    assert(n > 2), "degree 2 polynomial"
 
     z0F, thetaF = covariant_z0(compF, prec=prec, emb=emb)
     if norm_type == 'norm':
-         #euclidean norm squared
+        # euclidean norm squared
         normF = (sum([abs(i)**2 for i in compF.coefficients()]))
-        target = (2**(n-1))*normF/thetaF
+        target = (2**(n - 1)) * normF / thetaF
     elif norm_type == 'height':
         hF = exp(max([c.global_height(prec=prec) for c in F.coefficients()]))  # height
-        target = (2**(n-1))*(n+1)*(hF**2)/thetaF
+        target = (2**(n - 1)) * (n + 1) * (hF**2) / thetaF
     else:
         raise ValueError('type must be norm or height')
     return cosh(epsinv(F, target, prec=prec))
@@ -498,13 +500,13 @@ def smallest_poly(F, prec=53, norm_type='norm', emb=None):
         )
     """
     def insert_item(pts, item, index):
-        #binary insertion to maintain list of points left to consider
+        # binary insertion to maintain list of points left to consider
         N = len(pts)
         if N == 0:
-          return [item]
+            return [item]
         elif N == 1:
             if item[index] > pts[0][index]:
-                pts.insert(0,item)
+                pts.insert(0, item)
             else:
                 pts.append(item)
             return pts
@@ -512,72 +514,73 @@ def smallest_poly(F, prec=53, norm_type='norm', emb=None):
             left = 1
             right = N
             mid = (left + right) // 2  # these are ints so this is .floor()
-            if item[index] > pts[mid][index]: # item goes into first half
+            if item[index] > pts[mid][index]:  # item goes into first half
                 return insert_item(pts[:mid], item, index) + pts[mid:N]
-            else: # item goes into second half
+            else:  # item goes into second half
                 return pts[:mid] + insert_item(pts[mid:N], item, index)
+
     def coshdelta(z):
-        #The cosh of the hyperbolic distance from z = t+uj to j
-        return (z.norm() + 1)/(2*z.imag())#reduce in the sense of Cremona-Stoll
+        # The cosh of the hyperbolic distance from z = t+uj to j
+        return (z.norm() + 1)/(2*z.imag())  # reduce in the sense of Cremona-Stoll
     G = F
-    MG = matrix(ZZ,2,2,[1,0,0,1])
-    x,y = G.parent().gens()
+    MG = matrix(ZZ, 2, 2, [1, 0, 0, 1])
+    x, y = G.parent().gens()
     if norm_type == 'norm':
-        current_size = sum([abs(i)**2 for i in G.coefficients()]) #euclidean norm squared
-    elif norm_type == 'height': #height
+        current_size = sum([abs(i)**2 for i in G.coefficients()])  # euclidean norm squared
+    elif norm_type == 'height':  # height
         current_size = exp(max([c.global_height(prec=prec) for c in G.coefficients()]))
     else:
         raise ValueError('type must be norm or height')
     v0, th = covariant_z0(G, prec=prec, emb=emb)
-    rep = 2*CC.gen(0) #representative point in fundamental domain
+    rep = 2 * CC.gen(0)  # representative point in fundamental domain
     from math import isnan
     if isnan(v0.abs()):
-        raise ValueError("invalid covariant: %s"%v0)
+        raise ValueError("invalid covariant: %s" % v0)
     R = get_bound_poly(G, prec=prec, norm_type=norm_type)
 
-    #check orbit
-    S = matrix(ZZ,2,2,[0,-1,1,0])
-    T = matrix(ZZ,2,2,[1,1,0,1])
-    TI = matrix(ZZ,2,2,[1,-1,0,1])
+    # check orbit
+    S = matrix(ZZ, 2, 2, [0, -1, 1, 0])
+    T = matrix(ZZ, 2, 2, [1, 1, 0, 1])
+    TI = matrix(ZZ, 2, 2, [1, -1, 0, 1])
 
     count = 0
-    pts = [[G, v0, rep, MG, coshdelta(v0), 0]]  #label - 0:None, 1:S, 2:T, 3:T^(-1)
+    pts = [[G, v0, rep, MG, coshdelta(v0), 0]]  # label - 0:None, 1:S, 2:T, 3:T^(-1)
     current_min = [G, v0, rep, MG, coshdelta(v0)]
-    while pts != []:
+    while pts:
         G, v, rep, M, D, label = pts.pop()
-        #apply ST and keep z, Sz
+        # apply ST and keep z, Sz
         if D > R:
-            break #all remaining pts are too far away
-        #check if it is smaller. If so, we can improve the bound
+            break  # all remaining pts are too far away
+        # check if it is smaller. If so, we can improve the bound
         count += 1
         if norm_type == 'norm':
-            new_size = sum([abs(i)**2 for i in G.coefficients()]) #euclidean norm squared
-        else: #height
+            new_size = sum([abs(i)**2 for i in G.coefficients()])  # euclidean norm squared
+        else:  # height
             new_size = exp(max([c.global_height(prec=prec) for c in G.coefficients()]))
         if new_size < current_size:
             current_min = [G, v, rep, M, coshdelta(v)]
             current_size = new_size
             R = get_bound_poly(G, norm_type=norm_type, prec=prec, emb=emb)
 
-        #add new points to check
-        if label != 1 and min((rep+1).norm(), (rep-1).norm()) >= 1: #don't undo S
+        # add new points to check
+        if label != 1 and min((rep+1).norm(), (rep-1).norm()) >= 1:  # don't undo S
             # the 2nd condition is equivalent to |\Re(-1/rep)| <= 1/2
             # this means that rep can have resulted from an inversion step in
             # the shift-and-invert procedure, so don't invert
 
             # do inversion
-            z = -1/v
-            new_pt = [G.subs({x:-y, y:x}), z, -1/rep, M*S, coshdelta(z), 1]
+            z = -1 / v
+            new_pt = [G.subs({x: -y, y: x}), z, -1/rep, M*S, coshdelta(z), 1]
             pts = insert_item(pts, new_pt, 4)
-        if label != 3:  #don't undo TI
-            #do right shift
-            z = v-1
-            new_pt = [G.subs({x:x+y}), z, rep-1, M*T, coshdelta(z), 2]
+        if label != 3:  # don't undo TI
+            # do right shift
+            z = v - 1
+            new_pt = [G.subs({x: x + y}), z, rep-1, M*T, coshdelta(z), 2]
             pts = insert_item(pts, new_pt, 4)
-        if label != 2:  #don't undo T
-            #do left shift
-            z = v+1
-            new_pt = [G.subs({x:x-y}), z, rep+1, M*TI, coshdelta(z), 3]
+        if label != 2:  # don't undo T
+            # do left shift
+            z = v + 1
+            new_pt = [G.subs({x: x - y}), z, rep + 1, M * TI, coshdelta(z), 3]
             pts = insert_item(pts, new_pt, 4)
 
     return [current_min[0], current_min[3]]
