@@ -51,8 +51,6 @@ Functions
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
 
-from __future__ import print_function
-from __future__ import absolute_import
 
 import operator
 from sage.misc.cachefunc import cached_function
