@@ -8,7 +8,6 @@ TESTS::
     sage: x+z
     z + x
 """
-from __future__ import print_function
 
 import sage.misc.prandom as random
 
@@ -109,7 +108,8 @@ def absolute_number_field(maxdeg=10):
     R = ZZ['x']
     while True:
         f = R.random_element(degree=ZZ.random_element(x=1,y=maxdeg),x=-100,y=100)
-        if f.degree() <= 0: continue
+        if f.degree() <= 0:
+            continue
         f = f + R.gen()**(f.degree()+1)  # make monic
         if f.is_irreducible():
             return NumberField(f, 'a')
@@ -123,21 +123,32 @@ def relative_number_field(n=2, maxdeg=2):
         sage: import sage.rings.tests
         sage: sage.rings.tests.relative_number_field(3)
         Number Field in aaa with defining polynomial x^2 - 79*x - 53 over its base field
+
+    TESTS:
+
+    Check that :trac:`32117` is fixed::
+
+        sage: set_random_seed(3030)
+        sage: from sage.rings.tests import relative_number_field
+        sage: _ = relative_number_field(3)
     """
     from sage.all import ZZ
     K = absolute_number_field(maxdeg)
     n -= 1
     var = 'aa'
     R = ZZ['x']
+    R1 = K['x']
     while n >= 1:
         while True:
             f = R.random_element(degree=ZZ.random_element(x=1,y=maxdeg),x=-100,y=100)
-            if f.degree() <= 0: continue
+            if f.degree() <= 0:
+                continue
             f = f * f.denominator()  # bug trac #4781
             f = f + R.gen()**maxdeg  # make monic
-            if f.is_irreducible():
+            if R1(f).is_irreducible():
                 break
         K = K.extension(f,var)
+        R1 = K['x']
         var += 'a'
         n -= 1
     return K
@@ -315,7 +326,8 @@ def test_random_arith(level=MAX_LEVEL, trials=1):
               (i, get_memory_usage()))
         i += 1
         print(x)
-        a = x.random_element(); b = x.random_element()
+        a = x.random_element()
+        b = x.random_element()
         print(a, b)
         print(a*b+a-b+1)
         if i >= trials:
