@@ -6,8 +6,7 @@ AUTHORS:
 - Marco Streng (2010-07-20)
 
 """
-from __future__ import absolute_import
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2009/2010 Marco Streng <marco.streng@gmail.com>
 #
 #  Distributed under the terms of the GNU General Public License (GPL)
@@ -19,8 +18,8 @@ from __future__ import absolute_import
 #
 #  The full text of the GPL is available at:
 #
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
 from sage.rings.all import (AA, RLF, PolynomialRing)
 from sage.rings.rational_field import is_RationalField
@@ -48,7 +47,7 @@ class ProjectiveConic_number_field(ProjectiveConic_field):
         r"""
         See ``Conic`` for full documentation.
 
-        EXAMPLES ::
+        EXAMPLES::
 
             sage: Conic([1, 1, 1])
             Projective Conic Curve over Rational Field defined by x^2 + y^2 + z^2
@@ -62,9 +61,8 @@ class ProjectiveConic_number_field(ProjectiveConic_field):
         # all infinite primes such that self has no point over the completion
         self._infinite_obstructions = None
 
-
-    def has_rational_point(self, point = False, obstruction = False,
-                           algorithm = 'default', read_cache = True):
+    def has_rational_point(self, point=False, obstruction=False,
+                           algorithm='default', read_cache=True):
         r"""
         Returns ``True`` if and only if ``self`` has a point
         defined over its base field `B`.
@@ -199,13 +197,13 @@ class ProjectiveConic_number_field(ProjectiveConic_field):
                 else:
                     return False
             if (not point and not self._finite_obstructions and
-                        not self._infinite_obstructions):
+                    not self._infinite_obstructions):
                 if obstruction:
                     return True, None
                 return True
         if self.has_singular_point():
             if point:
-                return self.has_singular_point(point = True)
+                return self.has_singular_point(point=True)
             if obstruction:
                 return True, None
             return True
@@ -236,13 +234,13 @@ class ProjectiveConic_number_field(ProjectiveConic_field):
             if point:
                 raise ValueError("Algorithm 'local' cannot be combined "
                                  "with point = True in has_rational_point")
-            obs = self.local_obstructions(infinite = True, finite = False,
-                                          read_cache = read_cache)
+            obs = self.local_obstructions(infinite=True, finite=False,
+                                          read_cache=read_cache)
             if obs:
                 if obstruction:
                     return False, obs[0]
                 return False
-            obs = self.local_obstructions(read_cache = read_cache)
+            obs = self.local_obstructions(read_cache=read_cache)
             if not obs:
                 if obstruction:
                     return True, None
@@ -254,23 +252,23 @@ class ProjectiveConic_number_field(ProjectiveConic_field):
             from sage.modules.free_module_element import vector
             if obstruction:
                 raise ValueError("Algorithm rnfisnorm cannot be combined "
-                                  "with obstruction = True in "
-                                  "has_rational_point")
+                                 "with obstruction = True in "
+                                 "has_rational_point")
             D, T = self.diagonal_matrix()
-            abc = [D[0,0], D[1,1], D[2,2]]
+            abc = [D[0, 0], D[1, 1], D[2, 2]]
             for j in range(3):
                 if abc[j] == 0:
-                    pt = self.point(T*vector({2:0,j:1}))
+                    pt = self.point(T * vector({2: 0, j: 1}))
                     if point or obstruction:
                         return True, pt
                     return True
-            if (-abc[1]/abc[0]).is_square():
-                pt = self.point(T*vector([(-abc[1]/abc[0]).sqrt(), 1, 0]))
+            if (-abc[1] / abc[0]).is_square():
+                pt = self.point(T * vector([(-abc[1] / abc[0]).sqrt(), 1, 0]))
                 if point or obstruction:
                     return True, pt
                 return True
-            if (-abc[2]/abc[0]).is_square():
-                pt = self.point(T*vector([(-abc[2]/abc[0]).sqrt(), 0, 1]))
+            if (-abc[2] / abc[0]).is_square():
+                pt = self.point(T * vector([(-abc[2] / abc[0]).sqrt(), 0, 1]))
                 if point or obstruction:
                     return True, pt
                 return True
@@ -281,14 +279,14 @@ class ProjectiveConic_number_field(ProjectiveConic_field):
                 K = B.absolute_field('Y')
                 [KtoB, BtoK] = K.structure()
             X = PolynomialRing(K, 'X').gen()
-            d = BtoK(-abc[1]/abc[0])
+            d = BtoK(-abc[1] / abc[0])
             den = d.denominator()
-            L = K.extension(X**2 - d*den**2, names='y')
-            isnorm = BtoK(-abc[2]/abc[0]).is_norm(L, element=True)
+            L = K.extension(X**2 - d * den**2, names='y')
+            isnorm = BtoK(-abc[2] / abc[0]).is_norm(L, element=True)
             if isnorm[0]:
 
-                pt = self.point(T*vector([KtoB(isnorm[1][0]),
-                                          KtoB(isnorm[1][1]*den), 1]))
+                pt = self.point(T * vector([KtoB(isnorm[1][0]),
+                                          KtoB(isnorm[1][1] * den), 1]))
                 if point:
                     return True, pt
                 return True
@@ -302,9 +300,8 @@ class ProjectiveConic_number_field(ProjectiveConic_field):
             raise ValueError("Invalid combination: obstruction=True and "
                              "algorithm=%s" % algorithm)
 
-        return ProjectiveConic_field.has_rational_point(self, point = point,
-                           algorithm = algorithm, read_cache = False)
-
+        return ProjectiveConic_field.has_rational_point(self, point=point,
+                           algorithm=algorithm, read_cache=False)
 
     def is_locally_solvable(self, p):
         r"""
@@ -337,8 +334,8 @@ class ProjectiveConic_number_field(ProjectiveConic_field):
         for a in abc:
             if a == 0:
                 return True
-        a = -abc[0]/abc[2]
-        b = -abc[1]/abc[2]
+        a = -abc[0] / abc[2]
+        b = -abc[1] / abc[2]
 
         ret = self.base_ring().hilbert_symbol(a, b, p)
 
@@ -352,7 +349,7 @@ class ProjectiveConic_number_field(ProjectiveConic_field):
 
         return True
 
-    def local_obstructions(self, finite = True, infinite = True, read_cache = True):
+    def local_obstructions(self, finite=True, infinite=True, read_cache=True):
         r"""
         Returns the sequence of finite primes and/or infinite places
         such that ``self`` is locally solvable at those primes and places.
@@ -367,7 +364,7 @@ class ProjectiveConic_number_field(ProjectiveConic_field):
         Local obstructions are cached. The parameter ``read_cache``
         specifies whether to look at the cache before computing anything.
 
-        EXAMPLES ::
+        EXAMPLES::
 
             sage: K.<i> = QuadraticField(-1)
             sage: Conic(K, [1, 2, 3]).local_obstructions()
@@ -406,16 +403,14 @@ class ProjectiveConic_number_field(ProjectiveConic_field):
                             for f in O.fractional_ideal(a).factor():
                                 if f[1] < 0 and not f[0] in candidates:
                                     candidates.append(f[0])
-                    for f in O.fractional_ideal(2*self.determinant()).factor():
+                    for f in O.fractional_ideal(2 * self.determinant()).factor():
                         if f[1] > 0 and not f[0] in candidates:
                             candidates.append(f[0])
                 for b in candidates:
                     if not self.is_locally_solvable(b):
-                       obs1.append(b)
+                        obs1.append(b)
                 self._infinite_obstructions = obs1
         obs = obs1 + obs0
         if finite and infinite:
             assert len(obs) % 2 == 0
         return obs
-
-
